@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,148 +18,171 @@
  ******************************************************************************
  * Character of a team.
  *****************************************************************************/
-#include "body.h"
 #include <sstream>
 #include <iostream>
 #include <map>
-#include "clothe.h"
-#include "member.h"
-#include "../team/teams_list.h"
-#include "../game/time.h"
-#include "../tool/debug.h"
-#include "../tool/random.h"
-#include "../tool/resource_manager.h"
-#include "../tool/xml_document.h"
-#include "../particles/body_member.h"
-#include "../particles/teleport_member.h"
+#include "character/body.h"
+#include "character/character.h"
+#include "character/clothe.h"
+#include "character/member.h"
+#include "character/movement.h"
+#include "game/time.h"
+#include "graphic/sprite.h"
+#include "interface/mouse.h"
+#include "particles/body_member.h"
+#include "particles/teleport_member.h"
+#include "team/team.h"
+#include "team/teams_list.h"
+#include "tool/debug.h"
+#include "tool/random.h"
+#include "tool/resource_manager.h"
+#include "tool/xml_document.h"
 
-Body::Body(xmlpp::Element* xml, Profile* res)
+Body::Body(xmlNode* xml, const Profile* res):
+  members_lst(),
+  clothes_lst(),
+  mvt_lst(),
+  current_clothe(NULL),
+  current_mvt(NULL),
+  play_once_mvt_sauv(NULL),
+  play_once_clothe_sauv(NULL),
+  play_once_frame_sauv(0),
+  weapon_member(new WeaponMember()),
+  weapon_pos(0,0),
+  last_refresh(0),
+  current_frame(0),
+  walk_events(0),
+  main_rotation_rad(0),
+  squel_lst(),
+  direction(DIRECTION_RIGHT),
+  animation_number(0),
+  need_rebuild(false),
+  owner(NULL)
 {
-  need_rebuild = true;
-  current_clothe = NULL;
-  current_mvt = NULL;
-  walk_events = 0;
-  animation_number = 0;
-  direction = DIRECTION_RIGHT;
-  main_rotation_rad = 0;
+  xmlNodeArray nodes = XmlReader::GetNamedNeighbours(xml, "sprite");
+  xmlNodeArray::const_iterator it;
 
   // Load members
-  xmlpp::Node::NodeList nodes = xml -> get_children("sprite");
-  xmlpp::Node::NodeList::iterator it=nodes.begin();
-
-  while(it != nodes.end())
-   {
-    xmlpp::Element *elem = dynamic_cast<xmlpp::Element*> (*it);
+  MSG_DEBUG("body", "Found %i sprites\n", nodes.size());
+  for (it = nodes.begin(); it != nodes.end(); ++it)
+  {
     std::string name;
-    XmlReader::ReadStringAttr( elem, "name", name);
+    XmlReader::ReadStringAttr(*it, "name", name);
 
-    Member* member = new Member(elem, res);
-    if(members_lst.find(name) != members_lst.end())
+    Member* member = new Member(*it, res);
+    if (members_lst.find(name) != members_lst.end())
       std::cerr << "Warning !! The member \""<< name << "\" is defined twice in the xml file" << std::endl;
     else
       members_lst[name] = member;
+  } 
 
-    it++;
-  }
-
-  // Add a special weapon member to the body
-  weapon_member = new WeaponMember();
   members_lst["weapon"] = weapon_member;
 
   // Load clothes
-  xmlpp::Node::NodeList nodes2 = xml -> get_children("clothe");
-  xmlpp::Node::NodeList::iterator it2=nodes2.begin();
-
-  while(it2 != nodes2.end())
+  nodes = XmlReader::GetNamed(xml, "clothe");
+  MSG_DEBUG("body", "Found %i clothes\n", nodes.size());
+  for (it = nodes.begin(); it != nodes.end(); ++it)
   {
-    xmlpp::Element *elem = dynamic_cast<xmlpp::Element*> (*it2);
     std::string name;
-    XmlReader::ReadStringAttr( elem, "name", name);
+    XmlReader::ReadStringAttr(*it, "name", name);
 
-    Clothe* clothe = new Clothe(elem, members_lst);
+    Clothe* clothe = new Clothe(*it, members_lst);
     if (clothes_lst.find(name) != clothes_lst.end())
       std::cerr << "Warning !! The clothe \""<< name << "\" is defined twice in the xml file" << std::endl;
     else
       clothes_lst[name] = clothe;
-
-    it2++;
   }
 
   // Load movements alias
-  xmlpp::Node::NodeList nodes4 = xml -> get_children("alias");
-  xmlpp::Node::NodeList::iterator it4=nodes4.begin();
   std::map<std::string, std::string> mvt_alias;
-  while(it4 != nodes4.end())
-   {
-    xmlpp::Element *elem = dynamic_cast<xmlpp::Element*> (*it4);
+  nodes = XmlReader::GetNamedNeighbours(xml, "alias");
+  MSG_DEBUG("body", "Found %i aliases\n", nodes.size());
+  for (it = nodes.begin(); it != nodes.end(); ++it)
+  {
     std::string mvt, corresp;
-    XmlReader::ReadStringAttr( elem, "movement", mvt);
-    XmlReader::ReadStringAttr( elem, "correspond_to", corresp);
-    mvt_alias.insert(std::make_pair(mvt,corresp));
-    it4++;
+    XmlReader::ReadStringAttr(*it, "movement", mvt);
+    XmlReader::ReadStringAttr(*it, "correspond_to", corresp);
+    mvt_alias.insert(std::make_pair(mvt, corresp));
+    MSG_DEBUG("body", "  %s -> %s", mvt.c_str(), corresp.c_str());
   }
 
   // Load movements
-  xmlpp::Node::NodeList nodes3 = xml -> get_children("movement");
-  xmlpp::Node::NodeList::iterator it3=nodes3.begin();
-
-  while(it3 != nodes3.end())
+  nodes = XmlReader::GetNamedNeighbours(xml, "movement");
+  MSG_DEBUG("body", "Found %i movements\n", nodes.size());
+  for (it = nodes.begin(); it != nodes.end(); ++it)
   {
-    xmlpp::Element *elem = dynamic_cast<xmlpp::Element*> (*it3);
     std::string name;
-    XmlReader::ReadStringAttr( elem, "name", name);
-    if(strncmp(name.c_str(),"animation", 9)==0)
+    XmlReader::ReadStringAttr(*it, "name", name);
+    if (strncmp(name.c_str(),"animation", 9)==0)
       animation_number++;
 
-    Movement* mvt = new Movement(elem);
+    Movement* mvt = new Movement(*it);
     if(mvt_lst.find(name) != mvt_lst.end())
       std::cerr << "Warning !! The movement \""<< name << "\" is defined twice in the xml file" << std::endl;
     else
       mvt_lst[name] = mvt;
 
-    for(std::map<std::string, std::string>::iterator it = mvt_alias.begin();
-        it != mvt_alias.end();  ++it)
-    if(it->second == name)
-    {
-      Movement* mvt = new Movement(elem);
-      mvt->type = it->first;
-      mvt_lst[it->first] = mvt;
-    }
-    it3++;
+    for(std::map<std::string, std::string>::iterator iter = mvt_alias.begin();
+        iter != mvt_alias.end();  ++iter)
+      if (iter->second == name)
+      {
+        Movement* mvt = new Movement(*it);
+        mvt->type = iter->first;
+        mvt_lst[iter->first] = mvt;
+      }
   }
+
+  if ((mvt_lst.find("black") == mvt_lst.end() && clothes_lst.find("black") != clothes_lst.end())
+      || (mvt_lst.find("black") != mvt_lst.end() && clothes_lst.find("black") == clothes_lst.end()))
+  {
+    std::cerr << "Error: The movement \"black\" or the clothe \"black\" is not defined!" << std::endl;
+    exit(EXIT_FAILURE);
+  }
+
 }
 
-Body::Body(Body *_body)
+Body::Body(const Body& _body):
+  clothes_lst(),
+  mvt_lst(),
+  current_clothe(NULL),
+  current_mvt(NULL),
+  play_once_mvt_sauv(NULL),
+  play_once_clothe_sauv(NULL),
+  play_once_frame_sauv(0),
+  weapon_member(new WeaponMember()),
+  weapon_pos(0,0),
+  last_refresh(0),
+  current_frame(0),
+  walk_events(0),
+  main_rotation_rad(0),
+  squel_lst(),
+  direction(DIRECTION_RIGHT),
+  animation_number(_body.animation_number),
+  need_rebuild(true),
+  owner(NULL)
 {
-  need_rebuild = true;
-  current_clothe = NULL;
-  current_mvt = NULL;
-  walk_events = 0;
-  animation_number = _body->animation_number;
-  direction = DIRECTION_RIGHT;
-  main_rotation_rad = 0;
-
   // Add a special weapon member to the body
-  weapon_member = new WeaponMember();
   members_lst["weapon"] = weapon_member;
 
   // Make a copy of members
-  std::map<std::string, Member*>::iterator it1 = _body->members_lst.begin();
-  while(it1 != _body->members_lst.end())
-  if(it1->second->name != "weapon")
-  {
-    std::pair<std::string,Member*> p;
-    p.first = it1->first;
-    p.second = new Member(it1->second);
-    members_lst.insert(p);
-    it1++;
-  }
-  else
-    it1++;
+  std::map<std::string, Member*>::const_iterator it1 = _body.members_lst.begin();
+  while (it1 != _body.members_lst.end())
+    {
+      if(it1->second->name != "weapon")
+	{
+	  std::pair<std::string,Member*> p;
+	  p.first = it1->first;
+	  p.second = new Member(*it1->second);
+	  members_lst.insert(p);
+	  it1++;
+	}
+      else
+	it1++;
+    }
 
   // Make a copy of clothes
-  std::map<std::string, Clothe*>::iterator it2 = _body->clothes_lst.begin();
-  while(it2 != _body->clothes_lst.end())
+  std::map<std::string, Clothe*>::const_iterator it2 = _body.clothes_lst.begin();
+  while(it2 != _body.clothes_lst.end())
   {
     std::pair<std::string,Clothe*> p;
     p.first = it2->first;
@@ -169,8 +192,8 @@ Body::Body(Body *_body)
   }
 
   // Movement are shared
-  std::map<std::string, Movement*>::iterator it3 = _body->mvt_lst.begin();
-  while(it3 != _body->mvt_lst.end())
+  std::map<std::string, Movement*>::const_iterator it3 = _body.mvt_lst.begin();
+  while(it3 != _body.mvt_lst.end())
   {
     std::pair<std::string,Movement*> p;
     p.first = it3->first;
@@ -204,22 +227,31 @@ Body::~Body()
   mvt_lst.clear();
 }
 
-void Body::ResetMovement()
+void Body::ResetMovement() const
 {
-  for(int layer=0;layer < (int)current_clothe->layers.size() ;layer++)
+  for (int layer=0;layer < (int)current_clothe->layers.size() ;layer++)
     current_clothe->layers[layer]->ResetMovement();
 }
 
 void Body::ApplyMovement(Movement* mvt, uint frame)
 {
+#ifdef DEBUG
+  if (mvt->type != "breathe")
+    MSG_DEBUG("body_anim", " %s uses %s-%s:%u",
+	      owner->GetName().c_str(),
+	      current_clothe->name.c_str(),
+	      mvt->type.c_str(),
+	      frame);
+#endif
+
   // Move each member following the movement description
   // We do it using the order of the squeleton, as the movement of each
   // member affect the child members as well
   std::vector<junction>::iterator member = squel_lst.begin();
-  for(;member != squel_lst.end();
+  for (;member != squel_lst.end();
        member++)
   {
-    assert( frame < mvt->frames.size() );
+    ASSERT( frame < mvt->frames.size() );
     if(mvt->frames[frame].find(member->member->type) != mvt->frames[frame].end())
     {
       // This member needs to be moved :
@@ -275,8 +307,35 @@ void Body::ApplyMovement(Movement* mvt, uint frame)
           mb_mvt.SetAngle(mb_mvt.GetAngle() + M_PI);
       }
 
-
       member->member->ApplyMovement(mb_mvt, squel_lst);
+
+      // This movement needs to know the position of the member before
+      // being applied so it does a second ApplyMovement afterwards
+      // to be used
+      if(mb_mvt.follow_cursor && Mouse::GetInstance()->GetVisibility() == Mouse::MOUSE_VISIBLE)
+      {
+	member_mvt angle_mvt;
+
+	Point2i v = owner->GetPosition() + member->member->GetPos();
+	v += member->member->GetAnchorPos();
+
+	if( owner->GetDirection() == DIRECTION_LEFT)
+	{
+		v.x = 2 * (int)owner->GetPosition().x + GetSize().x/2 - v.x;
+		//v.x -= member->member->spr->GetWidth();
+	}
+	v = Mouse::GetInstance()->GetWorldPosition() - v;
+
+	if( v.Norm() < mb_mvt.follow_cursor_limit)
+	{
+          double angle = v.ComputeAngle(Point2i(0, 0));
+	  angle *= owner->GetDirection();
+	  angle -= owner->GetDirection() == DIRECTION_RIGHT ? M_PI:0;
+
+          angle_mvt.SetAngle(angle);
+          member->member->ApplyMovement(angle_mvt, squel_lst);
+	}
+      }
     }
   }
 }
@@ -286,8 +345,8 @@ void Body::ApplySqueleton()
   // Move each member following the squeleton
   std::vector<junction>::iterator member = squel_lst.begin();
   // The first member is the body, we set it to pos:
-  member->member->pos = Point2f(0,0);
-  member->member->SetAngle(0);
+  member->member->pos = Point2f(0.0, 0.0);
+  member->member->SetAngle(0.0);
   member++;
 
   for(;member != squel_lst.end();
@@ -302,29 +361,40 @@ void Body::Build()
 {
   // Increase frame number if needed
   unsigned int last_frame = current_frame;
-  if(walk_events > 0 || current_mvt->type!="walk")
-  if(Time::GetInstance()->Read() > last_refresh + current_mvt->speed)
-  {
-    current_frame += (Time::GetInstance()->Read()-last_refresh) / current_mvt->speed;
-    last_refresh += ((Time::GetInstance()->Read()-last_refresh) / current_mvt->speed) * current_mvt->speed;
 
-    if(current_frame >= current_mvt->frames.size())
+  if (walk_events > 0 || current_mvt->type != "walk")
     {
-      if(play_once_clothe_sauv)
-        SetClothe(play_once_clothe_sauv->name);
-      if(play_once_mvt_sauv)
-      {
-        SetMovement(play_once_mvt_sauv->type);
-        current_frame = play_once_frame_sauv;
-      }
-    }
-    current_frame %= current_mvt->frames.size();
-  }
+      if(Time::GetInstance()->Read() > last_refresh + current_mvt->speed)
+	{
+	  // Compute the new frame number
+	  current_frame += (Time::GetInstance()->Read()-last_refresh) / current_mvt->speed;
+	  last_refresh += ((Time::GetInstance()->Read()-last_refresh) / current_mvt->speed) * current_mvt->speed;
 
+	  // Depending on playmode loop if we have exceeded the nbr of frame of this movement
+	  if(current_frame >= current_mvt->frames.size())
+	    {
+	      if(current_mvt->play_mode == Movement::LOOP)
+		{
+		  current_frame %= current_mvt->frames.size();
+		}
+	      else if(current_mvt->play_mode == Movement::PLAY_ONCE)
+		{
+		  current_frame = current_mvt->frames.size() - 1;
+		  if (play_once_clothe_sauv)
+		    SetClothe(play_once_clothe_sauv->name);
+		  if (play_once_mvt_sauv)
+		    {
+		      SetMovement(play_once_mvt_sauv->type);
+		      current_frame = play_once_frame_sauv;
+		    }
+		}
+	    }
+	}
+    }
   need_rebuild |= (last_frame != current_frame);
   need_rebuild |= current_mvt->always_moving;
 
-  if(!need_rebuild)
+  if (!need_rebuild)
     return;
 
   ResetMovement();
@@ -333,20 +403,23 @@ void Body::Build()
 
   // Rotate each sprite, because the next part need to know the height of the sprite
   // once he is rotated
-  for(int layer=0;layer < (int)current_clothe->layers.size() ;layer++)
-  if(current_clothe->layers[layer]->name != "weapon")
-    current_clothe->layers[layer]->RotateSprite();
+  for (int layer=0;layer < (int)current_clothe->layers.size() ;layer++) {
+    if (current_clothe->layers[layer]->name != "weapon")
+      current_clothe->layers[layer]->RotateSprite();
+  }
 
   // Move the members to get the lowest member at the bottom of the skin rectangle
   member_mvt body_mvt;
   float y_max = 0;
-  for(int lay=0;lay < (int)current_clothe->layers.size() ;lay++)
-  if(current_clothe->layers[lay]->name != "weapon")
-  {
-    Member* member = current_clothe->layers[lay];
-    if(member->pos.y + member->spr->GetHeightMax() + member->spr->GetRotationPoint().y > y_max
-    && !member->go_through_ground)
-      y_max = member->pos.y + member->spr->GetHeightMax() + member->spr->GetRotationPoint().y;
+
+  for (int lay=0;lay < (int)current_clothe->layers.size() ;lay++) {
+    if (current_clothe->layers[lay]->name != "weapon")
+      {
+	Member* member = current_clothe->layers[lay];
+	if(member->pos.y + member->spr->GetHeightMax() + member->spr->GetRotationPoint().y > y_max
+	   && !member->go_through_ground)
+	  y_max = member->pos.y + member->spr->GetHeightMax() + member->spr->GetRotationPoint().y;
+      }
   }
   body_mvt.pos.y = (float)GetSize().y - y_max + current_mvt->test_bottom;
   body_mvt.pos.x = GetSize().x / 2.0 - squel_lst.front().member->spr->GetWidth() / 2.0;
@@ -356,19 +429,24 @@ void Body::Build()
   need_rebuild = false;
 }
 
-void Body::Draw(const Point2i& _pos)
+void Body::UpdateWeaponPosition(const Point2i& _pos)
 {
-  Build();
-
   // update the weapon position
-  if(direction == DIRECTION_RIGHT)
+  if (direction == DIRECTION_RIGHT)
     weapon_pos = Point2i((int)weapon_member->pos.x,(int)weapon_member->pos.y);
   else
     weapon_pos = Point2i(GetSize().x - (int)weapon_member->pos.x,(int)weapon_member->pos.y);
   weapon_pos += _pos;
+}
+
+void Body::Draw(const Point2i& _pos)
+{
+  Build();
+
+  UpdateWeaponPosition(_pos);
 
   // Finally draw each layer one by one
-  for(int layer=0;layer < (int)current_clothe->layers.size() ;layer++)
+  for (int layer=0;layer < (int)current_clothe->layers.size() ;layer++)
     current_clothe->layers[layer]->Draw(_pos, _pos.x + GetSize().x/2, int(direction));
 }
 
@@ -406,46 +484,45 @@ void Body::BuildSqueleton()
 
   // Find the "body" member as its the top of the squeleton
   for(uint lay = 0; lay < current_clothe->layers.size(); lay++)
-  if(current_clothe->layers[lay]->type == "body")
-  {
-    junction body;
-    body.member = current_clothe->layers[lay];
-    body.parent = NULL;
-    squel_lst.push_back(body);
-    break;
-  }
+    if(current_clothe->layers[lay]->type == "body")
+    {
+      junction body;
+      body.member = current_clothe->layers[lay];
+      body.parent = NULL;
+      squel_lst.push_back(body);
+      break;
+    }
 
   if(squel_lst.size() == 0)
   {
     std::cerr << "Unable to find the \"body\" member in the current clothe" << std::endl;
-    assert(false);
+    ASSERT(false);
   }
 
   AddChildMembers(squel_lst.front().member);
 }
 
-void Body::SetClothe(std::string name)
+void Body::SetClothe(const std::string& name)
 {
   MSG_DEBUG("body", " %s use clothe %s", owner->GetName().c_str(), name.c_str());
-  if(current_clothe && current_clothe->name == name) return;
+  if (current_clothe && current_clothe->name == name)
+    return;
 
-  if(clothes_lst.find(name) != clothes_lst.end())
+  if (clothes_lst.find(name) != clothes_lst.end())
   {
     current_clothe = clothes_lst.find(name)->second;
     BuildSqueleton();
     main_rotation_rad = 0;
     need_rebuild = true;
+    play_once_clothe_sauv = NULL;
   }
   else
-    MSG_DEBUG("body","Clothe not found");
+    MSG_DEBUG("body", "Clothe not found");
 
-
-  play_once_clothe_sauv = NULL;
-
-  assert(current_clothe != NULL);
+  ASSERT(current_clothe != NULL);
 }
 
-void Body::SetMovement(std::string name)
+void Body::SetMovement(const std::string& name)
 {
   MSG_DEBUG("body", " %s use movement %s", owner->GetName().c_str(), name.c_str());
   if(current_mvt && current_mvt->type == name) return;
@@ -460,13 +537,12 @@ void Body::SetMovement(std::string name)
     last_refresh = Time::GetInstance()->Read();
     main_rotation_rad = 0;
     need_rebuild = true;
+    play_once_mvt_sauv = NULL;
   }
   else
-    MSG_DEBUG("body","Movement not found");
+    MSG_DEBUG("body", "Movement not found");
 
-  play_once_mvt_sauv = NULL;
-
-  assert(current_mvt != NULL);
+  ASSERT(current_mvt != NULL);
 }
 
 void Body::PlayAnimation()
@@ -477,7 +553,7 @@ void Body::PlayAnimation()
   SetMovementOnce(name.str());
 }
 
-void Body::SetClotheOnce(std::string name)
+void Body::SetClotheOnce(const std::string& name)
 {
   MSG_DEBUG("body", " %s use clothe %s once", owner->GetName().c_str(), name.c_str());
   if(current_clothe && current_clothe->name == name) return;
@@ -492,12 +568,12 @@ void Body::SetClotheOnce(std::string name)
     need_rebuild = true;
   }
   else
-    MSG_DEBUG("body","Clothe not found");
+    MSG_DEBUG("body", "Clothe not found");
 
-  assert(current_clothe != NULL);
+  ASSERT(current_clothe != NULL);
 }
 
-void Body::SetMovementOnce(std::string name)
+void Body::SetMovementOnce(const std::string& name)
 {
   MSG_DEBUG("body", " %s use movement %s once", owner->GetName().c_str(), name.c_str());
   if(current_mvt && current_mvt->type == name) return;
@@ -520,12 +596,12 @@ void Body::SetMovementOnce(std::string name)
     need_rebuild = true;
   }
   else
-    MSG_DEBUG("body","Movement not found");
+    MSG_DEBUG("body", "Movement not found");
 
-  assert(current_mvt != NULL);
+  ASSERT(current_mvt != NULL);
 }
 
-void Body::GetTestRect(uint &l, uint&r, uint &t, uint &b)
+void Body::GetTestRect(uint &l, uint&r, uint &t, uint &b) const
 {
   if(direction == DIRECTION_RIGHT)
   {
@@ -541,21 +617,6 @@ void Body::GetTestRect(uint &l, uint&r, uint &t, uint &b)
   b = current_mvt->test_bottom;
 }
 
-void Body::SetDirection(Direction_t dir)
-{
-  direction=dir;
-}
-
-const Body::Direction_t &Body::GetDirection() const
-{
-  return direction;
-}
-
-const Point2i &Body::GetHandPosition() const
-{
-  return weapon_pos;
-}
-
 void Body::StartWalk()
 {
   // walk events happens when the player hits the left/right key
@@ -572,27 +633,30 @@ void Body::StopWalk()
   if(walk_events > 0)
     walk_events--;
   if(current_mvt->type == "walk")
+  {
+    SetMovement("breathe");
     SetFrame(0);
+  }
 }
 
-void Body::ResetWalk()
+bool Body::IsWalking() const
 {
-  walk_events = 0;
+  return walk_events > 0 /* && current_mvt->type == "walk" */;
 }
 
-uint Body::GetMovementDuration()
+uint Body::GetMovementDuration() const
 {
   return current_mvt->frames.size() * current_mvt->speed;
 }
 
-uint Body::GetFrameCount()
+uint Body::GetFrameCount() const
 {
   return current_mvt->frames.size();
 }
 
 void Body::SetFrame(uint no)
 {
-  assert(no < current_mvt->frames.size());
+  ASSERT(no < current_mvt->frames.size());
   current_frame = no;
   need_rebuild = true;
 }
@@ -615,9 +679,9 @@ void Body::MakeTeleportParticles(const Point2i& pos, const Point2i& dst)
   if(current_clothe->layers[layer]->type != "weapon")
   {
     ParticleEngine::AddNow(new TeleportMemberParticle(current_clothe->layers[layer]->spr,
-						      current_clothe->layers[layer]->GetPos()+pos,
-						      current_clothe->layers[layer]->GetPos()+dst,
-						      int(direction)));
+                                                      current_clothe->layers[layer]->GetPos()+pos,
+                                                      current_clothe->layers[layer]->GetPos()+dst,
+                                                      int(direction)));
   }
 }
 
@@ -628,5 +692,15 @@ void Body::SetRotation(double angle)
   need_rebuild = true;
 }
 
-const std::string& Body::GetMovement() { return current_mvt->type; }
-const std::string& Body::GetClothe() { return current_clothe->name; }
+const std::string& Body::GetMovement() const { return current_mvt->type; }
+const std::string& Body::GetClothe() const { return current_clothe->name; }
+
+void Body::DebugState() const
+{
+  MSG_DEBUG("body.state", "clothe: %s\tmovement: %s\t%i", current_clothe->name.c_str(),current_mvt->type.c_str(), current_frame);
+  MSG_DEBUG("body.state", "(played once)clothe: %s\tmovement: %s",
+            (play_once_clothe_sauv?play_once_clothe_sauv->name.c_str():"(NULL)"),
+            (play_once_mvt_sauv?play_once_mvt_sauv->type.c_str():"(NULL)"),
+            play_once_frame_sauv);
+  MSG_DEBUG("body.state", "need rebuild = %i",need_rebuild);
+}
