@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,13 +21,10 @@
 #ifndef CLOTHE_H
 #define CLOTHE_H
 #include <map>
-#include "member.h"
-#include "../graphic/sprite.h"
-#include "../tool/resource_manager.h"
-#include "../tool/point.h"
-#include "../tool/xml_document.h"
+#include <vector>
 
 class Member;
+typedef struct _xmlNode xmlNode;
 
 class Clothe
 {
@@ -36,7 +33,7 @@ public:
   std::vector<Member*> layers;
 
   ~Clothe();
-  Clothe(xmlpp::Element *xml, std::map<std::string, Member*>& members_lst);
+  Clothe(xmlNode* xml, std::map<std::string, Member*>& members_lst);
   Clothe(Clothe* c, std::map<std::string, Member*>& members_lst);
 };
 
