@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,14 +24,17 @@
 #define GAME_MODE_H
 
 #include <string>
-#include "../include/base.h"
-#include "../tool/xml_document.h"
-#include "../weapon/weapon_cfg.h"
+#include "include/base.h"
+#include "include/singleton.h"
+#include "weapon/weapon_cfg.h"
 
-class GameMode
+typedef struct _xmlNode xmlNode;
+class XmlReader;
+
+class GameMode : public Singleton<GameMode>
 {
 public:
-  uint max_characters;
+  uint nb_characters;
   uint max_teams;
   uint duration_turn;
   uint duration_move_player;
@@ -57,31 +60,51 @@ public:
     double super_jump_angle;
     uint back_jump_strength;
     double back_jump_angle;
+    uint walking_pause;
   } character;
 
   int allow_character_selection;
 
-  static const int ALWAYS = 0;
-  static const int BEFORE_FIRST_ACTION = 1;
-  static const int BEFORE_FIRST_ACTION_AND_END_TURN = 2;
-  static const int CHANGE_ON_END_TURN = 3;
-  static const int NEVER = 4;
-
+  enum {
+    ALWAYS = 0,
+    BEFORE_FIRST_ACTION,
+    BEFORE_FIRST_ACTION_AND_END_TURN,
+    CHANGE_ON_END_TURN,
+    NEVER
+  };
 private:
   std::string m_current;
-  static GameMode * singleton;
+
+  XmlReader* doc_objects;
+
+  bool LoadXml (xmlNode* xml);
+  bool ExportFileToString(const std::string& filename, std::string& contents) const;
+
+  std::string GetFilename() const;
+  std::string GetObjectsFilename() const;
 
 public:
-  static GameMode * GetInstance();
+  const std::string& GetName() const;
+
+  bool Load(void);
+
+  // mode: xml text of data/game_mode/<mode>.xml
+  // mode_objects: xml text of data/game_mode/<mode>_objects.xml
+  bool LoadFromString(const std::string& game_mode_name,
+                      const std::string& mode,
+                      const std::string& mode_objects);
+
+  bool ExportToString(std::string& mode,
+                      std::string& mode_objects) const;
+
+  const XmlReader* GetXmlObjects() const; // for object_cfg
 
-  bool Load(const std::string &mode);
   bool AllowCharacterSelection() const;
 
-private:
-  GameMode();
-
 protected:
-  bool LoadXml (xmlpp::Element *xml);
+  friend class Singleton<GameMode>;
+  GameMode();
+  ~GameMode();
 };
 
 #endif /* GAME_MODE_H */
