@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,40 +23,52 @@
 #define TIME_H
 
 #include <string>
-#include "../include/base.h"
+#include "include/base.h"
+#include "include/singleton.h"
 
-class Time
+// XXX uint wrap-around (or at least system timer) not handled
+class Time : public Singleton<Time>
 {
 private:
-  uint current_time;
-  uint max_time;
-  uint delta_t;
-  bool is_game_paused;
-  static Time * singleton;
+  uint        current_time;
+  //uint        max_time;
+  uint        delta_t;
+  bool        is_game_paused;
 
-private:
+  uint        real_time_game_start;
+  uint        real_time_pause_dt;
+  uint        real_time_pause_begin;
+
+protected:
+  friend class Singleton<Time>;
   Time();
+
 public:
-  static Time * GetInstance();
 
   void Reset();
   bool IsGamePaused() const;
 
   // Read the time of the game, excluding paused time
-  uint Read() const;
-  uint ReadSec() const;
-  uint ReadMin() const;
+  uint ReadRealTime() const;
+  uint Read() const { return current_time; };
+  uint ReadDuration() const
+  {
+    return current_time-real_time_game_start-real_time_pause_dt;
+  };
+  uint ReadSec() const { return Read() / 1000; };
+  uint ReadMin() const { return ReadSec() / 60; };
   void Refresh();
-  uint GetDelta() const;
-  void RefreshMaxTime(uint updated_max_time);
+  uint GetDelta() const { return delta_t; };
+  //void RefreshMaxTime(uint updated_max_time);
 
   // Read the clock time
-  uint ClockSec();  // ReadSec() % 60
-  uint ClockMin();  // ReadMin() % 60
-  std::string GetString();
+  uint ClockSec() const { return ReadSec() % 60; };
+  uint ClockMin() const { return ReadMin() % 60; };
+  std::string GetString() const;
 
   void Pause();
   void Continue();
+  void TogglePause();
 };
 
 #endif
