@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,54 +19,61 @@
  * Handle a color
  *****************************************************************************/
 
-#include "color.h"
+#include "graphic/color.h"
 #include <SDL.h>
 
 Color::Color(){
-	SetColor(200, 50, 50, 130);
+        SetColor(200, 50, 50, 130);
 }
 
 Color::Color(Uint8 r, Uint8 g, Uint8 b, Uint8 a){
-	SetColor(r, g, b, a);
+        SetColor(r, g, b, a);
 }
 
 bool Color::operator==(const Color &color) const{
-	return red == color.red 
-		&& green == color.green 
-		&& blue == color.blue 
-		&& alpha == color.alpha;
+        return red == color.red
+               && green == color.green
+               && blue == color.blue
+               && alpha == color.alpha;
+}
+
+bool Color::operator!=(const Color & color) const{
+        return red != color.red
+	  || green != color.green
+	  || blue != color.blue
+	  || alpha != color.alpha;
+}
+
+Color Color::operator*(const Color &fact) const{
+        return Color((Uint8) ((Uint32)red * fact.red / 255),
+                     (Uint8) ((Uint32)green * fact.green / 255),
+                     (Uint8) ((Uint32)blue * fact.blue / 255),
+                     (Uint8) ((Uint32)alpha * fact.alpha / 255));
 }
 
 void Color::SetColor(Uint8 r, Uint8 g, Uint8 b, Uint8 a){
-	red = r;
-	green = g;
-	blue = b;
-	alpha = a;
-}
-
-Uint8 Color::GetRed() const{
-	return red;
-}
-
-Uint8 Color::GetGreen() const{
-	return green;
-}
-
-Uint8 Color::GetBlue() const{
-	return blue;
-}
-
-Uint8 Color::GetAlpha() const{
-	return alpha;
+        red = r;
+        green = g;
+        blue = b;
+        alpha = a;
 }
 
 SDL_Color Color::GetSDLColor() const{
-	SDL_Color sdlColor;
+        SDL_Color sdlColor;
 
-	sdlColor.r = red;
-	sdlColor.g = green;
-	sdlColor.b = blue;
-	sdlColor.unused = alpha;
+        sdlColor.r = red;
+        sdlColor.g = green;
+        sdlColor.b = blue;
+        sdlColor.unused = alpha;
 
-	return sdlColor;
+        return sdlColor;
+}
+
+Uint32 Color::GetColor() const
+{
+#if SDL_BYTEORDER == SDL_LIL_ENDIAN
+  return (red << 24) | green << 16 | blue << 8 | alpha;
+#else
+  return (alpha << 24) | blue << 16 | green << 8 | red;
+#endif
 }
