@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,8 +21,10 @@
 #ifndef EFFECTS_H
 #define EFFECTS_H
 
-#include <SDL.h>
-#include "sprite.h"
+#include "include/base.h"
+
+class Sprite;
+class Surface;
 
 Sprite* WaveSurface(Surface &a, unsigned int nbr_frames, unsigned int duration, float wave_amp, float wave_per);
 void Rebound(Sprite* spr, int &y, uint t0, uint per, int dy_max);
