@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,70 +17,85 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  ******************************************************************************/
 
-#include <exception>
-#include <SDL_image.h>
-#include <SDL_video.h>
 #include <iostream>
-#include <string>
-#include "font.h"
-#include "colors.h"
-#include "../game/config.h"
-#include "../include/app.h"
-#include "../map/map.h"
-#include "../tool/error.h"
-#include "../tool/file_tools.h"
+#include "graphic/font.h"
+#include "game/config.h"
+#include "graphic/video.h"
+#include "include/app.h"
+#include "map/map.h"
+#include "tool/file_tools.h"
+#include "tool/i18n.h"
 
 Font* Font::FONT_ARRAY[] = {NULL, NULL, NULL, NULL, NULL, NULL};
 Font* Font::FONT_ARRAY_BOLD[] = {NULL, NULL, NULL, NULL, NULL, NULL};
 Font* Font::FONT_ARRAY_ITALIC[] = {NULL, NULL, NULL, NULL, NULL, NULL};
+bool  Font::LIB_INIT = false;
 
 /*
  * Constants
  */
 // Size
 const int Font::FONT_SIZE[] = {40, 32, 24, 16, 12, 8};
-const int Font::FONT_HUGE   = 0;
-const int Font::FONT_LARGE  = 1;
-const int Font::FONT_BIG    = 2;
-const int Font::FONT_NORMAL = 3;
-const int Font::FONT_SMALL  = 4;
-const int Font::FONT_TINY   = 5;
 
-// Style
-const int Font::NORMAL = 0;
-const int Font::BOLD   = 1;
-const int Font::ITALIC = 2;
+Font* Font::GetInstance(font_size_t ftype, font_style_t fstyle) {
+  Font * font = NULL;
+  int type = (int)ftype;
 
-Font* Font::GetInstance(int type, int font_style) {
-  Font * font;
-  if (FONT_ARRAY[type] == NULL) {
-    switch(font_style) {
-      case BOLD:
-        font = FONT_ARRAY_BOLD[type] = new Font(FONT_SIZE[type]);
-        font->SetBold();
-        break;
-      case ITALIC:
-        font = FONT_ARRAY_ITALIC[type] = new Font(FONT_SIZE[type]);
-        font->SetItalic();
-        break;
-      default:     font = FONT_ARRAY[type] = new Font(FONT_SIZE[type]); break;
+  if (FONT_ARRAY[ftype] == NULL) {
+    try {
+      if (!LIB_INIT && TTF_Init() == -1) {
+        Error(Format("Initialisation of TTF library failed: %s", TTF_GetError()));
+        exit(1);
+      }
+      LIB_INIT = true;
+
+      // Load the font in the different styles
+      FONT_ARRAY_BOLD[type] = new Font(FONT_SIZE[type]);
+      FONT_ARRAY_BOLD[type]->SetBold();
+
+      FONT_ARRAY_ITALIC[type] = new Font(FONT_SIZE[type]);
+      FONT_ARRAY_ITALIC[type]->SetItalic();
+
+      FONT_ARRAY[type] = new Font(FONT_SIZE[type]);
     }
-  } else {
-    switch(font_style) {
-      case BOLD:   font = FONT_ARRAY_BOLD[type]; break;
-      case ITALIC: font = FONT_ARRAY_ITALIC[type]; break;
-      default  :   font = FONT_ARRAY[type]; break;
+
+    catch (const std::string e)
+    {
+      std::cerr << e << std::endl;
+      exit(-1);
     }
   }
+
+  switch(fstyle) {
+  case FONT_BOLD:
+    font = FONT_ARRAY_BOLD[type];
+    break;
+  case FONT_ITALIC:
+    font = FONT_ARRAY_ITALIC[type];
+    break;
+  case FONT_NORMAL:
+    font = FONT_ARRAY[type];
+    break;
+  }
   return font;
 }
 
-Font::Font(int size){
-  m_font = NULL;
-  bool ok = Load(Config::GetInstance()->GetTtfFilename(), size);
-  
-  if( !ok )
-    Error("Error during initialisation of a font!");
+Font::Font(int size):
+  surface_text_table(),
+  m_font(NULL)
+{
+  const std::string filename = Config::GetInstance()->GetTtfFilename();
+
+  if (DoesFileExist(filename))
+  {
+    m_font = TTF_OpenFont(filename.c_str(), size);
+    if (!m_font)
+      Error("Error in font file");
+  }
+  else
+    Error("Can't find font file");
+
+  TTF_SetFontStyle(m_font, TTF_STYLE_NORMAL);
 }
 
 Font::~Font(){
@@ -88,33 +103,46 @@ Font::~Font(){
     TTF_CloseFont(m_font);
     m_font = NULL;
   }
-  
+
   txt_iterator it;
-  
-  for( it = surface_text_table.begin(); 
-       it != surface_text_table.end(); 
-       ++it ){
-    //SDL_FreeSurface(it->second);
-    surface_text_table.erase(it->first);
-  }
+
+  // Fix bug #10866 and also fix memory leak.
+  surface_text_table.clear();
 }
 
-bool Font::Load (const std::string& filename, int size) {
-  bool ok = false;
+void Font::ReleaseInstances(void)
+{
+  uint i;
 
-  if( IsFileExist(filename) ){
-      m_font = TTF_OpenFont(filename.c_str(), size);
-      ok = (m_font != NULL);
+  for (i=0; i<sizeof(FONT_ARRAY)/sizeof(Font*); i++)
+  {
+    if (FONT_ARRAY[i])
+    {
+      delete FONT_ARRAY[i];
+      FONT_ARRAY[i] = NULL;
+    }
   }
-  
-  if( !ok ){
-      std::cout << "Error: Font " << filename << " can't be found!" << std::endl;
-      return false;
-  }
-  
-  TTF_SetFontStyle(m_font, TTF_STYLE_NORMAL);
 
-  return true;
+  for (i=0; i<sizeof(FONT_ARRAY_BOLD)/sizeof(Font*); i++)
+  {
+    if (FONT_ARRAY_BOLD[i])
+    {
+      delete FONT_ARRAY_BOLD[i];
+      FONT_ARRAY_BOLD[i] = NULL;
+    }
+  }
+
+  for (i=0; i<sizeof(FONT_ARRAY_ITALIC)/sizeof(Font*); i++)
+  {
+    if (FONT_ARRAY_ITALIC[i])
+    {
+      delete FONT_ARRAY_ITALIC[i];
+      FONT_ARRAY_ITALIC[i] = NULL;
+    }
+  }
+
+  TTF_Quit();
+  LIB_INIT = false;
 }
 
 void Font::SetBold()
@@ -127,40 +155,41 @@ void Font::SetItalic()
   TTF_SetFontStyle(m_font, TTF_STYLE_ITALIC);
 }
 
-void Font::Write(const Point2i &pos, Surface &surface){
-  AppWormux::GetInstance()->video.window.Blit(surface, pos);
-		  
+void Font::Write(const Point2i& pos, const Surface &surface) const {
+  AppWormux::GetInstance()->video->window.Blit(surface, pos);
+
   // TODO: Remove this line! (and use GameFont instead of Font)
   world.ToRedrawOnScreen( Rectanglei(pos, surface.GetSize()) );
 }
 
-void Font::WriteLeft(const Point2i &pos, const std::string &txt,  const Color &color){
+void Font::WriteLeft(const Point2i &pos, const std::string &txt,
+                     const Color &color){
   Surface surface(Render(txt, color, true));
   Write(pos, surface);
 }
 
 void Font::WriteLeftBottom(const Point2i &pos, const std::string &txt,
-			     const Color &color){ 
+                           const Color &color){
   Surface surface(Render(txt, color, true));
   Write(pos - Point2i(0, surface.GetHeight()), surface);
 }
 
 void Font::WriteRight(const Point2i &pos, const std::string &txt,
-		        const Color &color){ 
+                      const Color &color){
   Surface surface(Render(txt, color, true));
   Write(pos - Point2i(surface.GetWidth(), 0), surface);
 }
 
 void Font::WriteCenter (const Point2i &pos, const std::string &txt,
-			 const Color &color){ 
+                        const Color &color){
   Surface surface(Render(txt, color, true));
   Write(pos - Point2i(surface.GetWidth()/2, surface.GetHeight()), surface);
 }
 
 void Font::WriteCenterTop(const Point2i &pos, const std::string &txt,
-		const Color &color){
-	Surface surface(Render(txt, color, true));
-	Write(pos - Point2i(surface.GetWidth()/2, 0), surface);
+                          const Color &color){
+  Surface surface(Render(txt, color, true));
+  Write(pos - Point2i(surface.GetWidth()/2, 0), surface);
 }
 
 Surface Font::CreateSurface(const std::string &txt, const Color &color){
@@ -169,10 +198,10 @@ Surface Font::CreateSurface(const std::string &txt, const Color &color){
 
 Surface Font::Render(const std::string &txt, const Color &color, bool cache){
   Surface surface;
-  
+
   if( cache ){
     txt_iterator p = surface_text_table.find(txt);
-    if( p == surface_text_table.end() ){ 
+    if( p == surface_text_table.end() ){
       if( surface_text_table.size() > 5 ){
         //SDL_FreeSurface( surface_text_table.begin()->second );
         surface_text_table.erase( surface_text_table.begin() );
@@ -180,36 +209,42 @@ Surface Font::Render(const std::string &txt, const Color &color, bool cache){
       surface = CreateSurface(txt, color);
       surface_text_table.insert( txt_sample(txt, surface) );
     } else {
-      txt_iterator p = surface_text_table.find( txt );
-      surface = p->second;
+      txt_iterator p2 = surface_text_table.find( txt );
+      surface = p2->second;
     }
   } else
     surface = CreateSurface(txt, color);
-  
-  assert( !surface.IsNull() );
+
+  ASSERT( !surface.IsNull() );
   return surface;
 }
 
-int Font::GetWidth (const std::string &txt){ 
+int Font::GetWidth (const std::string &txt) const {
   int width=-1;
-  
+
   TTF_SizeUTF8(m_font, txt.c_str(), &width, NULL);
 
   return width;
 }
 
-int Font::GetHeight (){ 
+int Font::GetHeight () const {
   return TTF_FontHeight(m_font);
 }
 
-int Font::GetHeight (const std::string &str){ 
+int Font::GetHeight (const std::string &str) const {
   int height=-1;
-  
+
   TTF_SizeUTF8(m_font, str.c_str(), NULL, &height);
 
   return height;
 }
 
-Point2i Font::GetSize(const std::string &txt){
-	return Point2i(GetWidth(txt), GetHeight(txt));
+Point2i Font::GetSize(const std::string &txt) const {
+  return Point2i(GetWidth(txt), GetHeight(txt));
+}
+
+Surface Font::GenerateSurface(const std::string &txt, const Color &color,
+                              font_size_t font_size, font_style_t font_style)
+{
+  return Surface(Font::GetInstance(font_size, font_style)->CreateSurface(txt, color));
 }
