@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,66 +16,82 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  ******************************************************************************/
- 
+
 #ifndef FONT_H
 #define FONT_H
 #include <SDL.h>
 #include <SDL_ttf.h>
 #include <map>
-#include "../include/base.h"
+#include "include/base.h"
 #include "colors.h"
 #include "surface.h"
 
-class GameLoop;
+// Forward declarations
+class Game;
 
 class Font
 {
 private:
-  typedef std::map<std::string, Surface>::value_type 
+
+  /* If you need this, implement it */
+  Font(const Font&);
+  Font operator=(const Font&);
+  /**********************************/
+
+  typedef std::map<std::string, Surface>::value_type
     txt_sample;
-  typedef std::map<std::string, Surface>::iterator 
+  typedef std::map<std::string, Surface>::iterator
     txt_iterator;
   static const int FONT_SIZE[];
   static Font* FONT_ARRAY[6];
   static Font* FONT_ARRAY_BOLD[6];
   static Font* FONT_ARRAY_ITALIC[6];
+  static bool  LIB_INIT;
 
   std::map<std::string, Surface> surface_text_table;
   TTF_Font *m_font;
-  void Write(const Point2i &pos, Surface &surface);
+  void Write(const Point2i &pos, const Surface &surface) const;
 
   Font(int size);
 
 public:
   // Size
-  static const int FONT_HUGE;
-  static const int FONT_LARGE;
-  static const int FONT_BIG;
-  static const int FONT_NORMAL;
-  static const int FONT_SMALL;
-  static const int FONT_TINY;
+  typedef enum {
+    FONT_HUGE = 0,
+    FONT_LARGE = 1,
+    FONT_BIG = 2,
+    FONT_MEDIUM = 3,
+    FONT_SMALL = 4,
+    FONT_TINY = 5
+  } font_size_t;
+
   // Style
-  static const int NORMAL;
-  static const int BOLD;
-  static const int ITALIC;
+  typedef enum {
+    FONT_NORMAL = 0,
+    FONT_BOLD = 1,
+    FONT_ITALIC = 2,
+  } font_style_t;
 
   // type: defined as static consts above
-  static Font* GetInstance(int type, int font_style = NORMAL);
+  static Font* GetInstance(font_size_t size, font_style_t style = FONT_NORMAL);
+  static void ReleaseInstances(void);
 
   ~Font();
 
-  bool Load (const std::string& filename, int size);
+  static Surface GenerateSurface(const std::string &txt, const Color &color,
+                                 font_size_t size = FONT_MEDIUM, font_style_t style = FONT_NORMAL);
 
   void WriteLeft(const Point2i &pos, const std::string &txt, const Color &color);
   void WriteLeftBottom(const Point2i &pos, const std::string &txt, const Color &color);
   void WriteRight(const Point2i &pos, const std::string &txt, const Color &color);
   void WriteCenterTop(const Point2i &pos, const std::string &txt, const Color &color);
   void WriteCenter(const Point2i &pos, const std::string &txt, const Color &color);
-  
-  int GetWidth(const std::string &txt);
-  int GetHeight();
-  int GetHeight(const std::string &txt);
-  Point2i GetSize(const std::string &txt);
+
+  static int GetPointSize(font_size_t size) { return FONT_SIZE[size]; };
+  int GetWidth(const std::string &txt) const;
+  int GetHeight() const;
+  int GetHeight(const std::string &txt) const;
+  Point2i GetSize(const std::string &txt) const;
 
   Surface Render(const std::string &txt, const Color &color, bool cache=false);
   Surface CreateSurface(const std::string &txt, const Color &color);
