@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,41 +19,37 @@
  * Calculate frame per second.
  *****************************************************************************/
 
-#include "fps.h"
-#include <SDL.h>
-#include <sstream>
-#include <iomanip>
-#include "colors.h"
-#include "video.h"
-#include "text.h"
-#include "../include/app.h"
-#include "../tool/i18n.h"
+#include "graphic/fps.h"
+#include "graphic/text.h"
+#include "graphic/video.h"
+#include "include/app.h"
+#include "tool/i18n.h"
 
 const uint FramePerSecond::MIN_NB_VALUES = 4;
-  
+
 FramePerSecond::~FramePerSecond(){
   delete text;
-}    
+}
 
-FramePerSecond::FramePerSecond(){
-  text = NULL;
-  display = true;
-  average = -1;
-  
+FramePerSecond::FramePerSecond():
+  nb_valid_values(-1),
+  average(-1),
+  nb_frames(),
+  time_in_second(0),
+  text(NULL),
+  display(true)
+{
   for( uint i=0; i<=MIN_NB_VALUES; ++i )
     nb_frames.push_back (0);
-  
-  time_in_second = 0;
-  nb_valid_values = -1;
 }
 
 void FramePerSecond::Reset(){
   average = -1;
   nb_frames.clear();
-  
+
   for( uint i=0; i<=MIN_NB_VALUES; ++i )
     nb_frames.push_back (0);
-  
+
   time_in_second = SDL_GetTicks()+1000;
   nb_valid_values = -1;
 
@@ -67,13 +63,13 @@ void FramePerSecond::AddOneFrame(){
 
 void FramePerSecond::Refresh()
 {
-  uint nv_temps = SDL_GetTicks();   
-   
-  // Pas encore l'heure de recalculer : exit !
+  uint nv_temps = SDL_GetTicks();
+
+  // Not yet time to compute: exit!
   if (nv_temps <= time_in_second)
     return;
 
-  // On dcale !
+  // Shift position!
   while (time_in_second < nv_temps){
     time_in_second += 1000;
     nb_frames.pop_back();
@@ -82,7 +78,7 @@ void FramePerSecond::Refresh()
       nb_valid_values++;
   }
 
-  // Recalcule la average
+  // Recompute average
   if (0 < nb_valid_values){
     average = 0;
     std::list<uint>::const_iterator it=nb_frames.begin();
@@ -98,12 +94,12 @@ void FramePerSecond::Draw(){
     return;
   if( average < 0 )
     return;
-  
+
   char buffer[20];
-  
+
   snprintf(buffer, sizeof(buffer)-1, "%.1f", average);
   buffer[sizeof(buffer)-1] = '\0';
   text->Set (Format(_("%s fps"), buffer));
-  text->DrawTopRight(AppWormux::GetInstance()->video.window.GetWidth()-1,0);
+  text->DrawTopRight(Point2i(AppWormux::GetInstance()->video->window.GetWidth()-1,0));
 }
 
