@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,23 +22,23 @@
  *             Initial version
  *****************************************************************************/
 
-#include "spritecache.h"
-#include <SDL_rotozoom.h>
+#include "graphic/spritecache.h"
+#include "graphic/sprite.h"
 
-#define BUGGY_SDLGFX
-
-SpriteFrameCache::SpriteFrameCache() {
+SpriteFrameCache::SpriteFrameCache() 
+{
   use_rotation = false;
 }
-#include <iostream>
-void SpriteFrameCache::CreateRotationCache(Surface &surface, unsigned int cache_size){
-  assert (use_rotation == false);
+
+void SpriteFrameCache::CreateRotationCache(Surface &surface, unsigned int cache_size, bool smooth)
+{
+  ASSERT (use_rotation == false);
   use_rotation = true;
 
   rotated_surface.push_back( surface );
   for(unsigned int i=1 ; i< cache_size ; i++){
     double angle = 2* M_PI * (1 /* to inverte rotation angle */ - static_cast<double>(i) / static_cast<double>(cache_size));
-    rotated_surface.push_back( surface.RotoZoom(angle, 1.0, 1.0, SMOOTHING_ON) );
+    rotated_surface.push_back( surface.RotoZoom(angle, 1.0, 1.0, smooth) );
   }
 }
 
@@ -65,20 +65,20 @@ Surface SpriteFrameCache::GetSurfaceForAngle(double angle) const
   return rotated_surface[index];
 }
 
-void SpriteFrameCache::CreateFlippingCache(Surface &surface)
+void SpriteFrameCache::CreateFlippingCache(Surface &surface, bool smooth)
 {
-  assert (flipped_surface.IsNull());
-  flipped_surface = surface.RotoZoom( 0.0, -1.0, 1.0, SMOOTHING_OFF);
+  ASSERT (flipped_surface.IsNull());
+  flipped_surface = surface.RotoZoom( 0.0, -1.0, 1.0, smooth);
   if (use_rotation)
   {
-    assert (rotated_surface.size() != 0);
-    assert (rotated_flipped_surface.size() == 0);
+    ASSERT (rotated_surface.size() != 0);
+    ASSERT (rotated_flipped_surface.size() == 0);
     rotated_flipped_surface.push_back( flipped_surface );
     const unsigned int n = rotated_surface.size();
     for(unsigned int i=1 ; i<n; i++)
     {
       double angle = 2 * M_PI * (1 - (float) i / (float) n);
-      rotated_flipped_surface.push_back( surface.RotoZoom(angle, -1.0, 1.0, SMOOTHING_ON) );
+      rotated_flipped_surface.push_back( surface.RotoZoom(angle, -1.0, 1.0, smooth) );
     }
   }
 }
@@ -107,16 +107,16 @@ SpriteCache::SpriteCache(Sprite &p_sprite, const SpriteCache &other)  :
 
   for ( unsigned int f = 0 ; f < other.frames.size() ; f++)
   {
-    Surface new_surf = Surface(frame_width_pix, frame_height_pix, SDL_SWSURFACE|SDL_SRCALPHA, true);
+    Surface new_surf(frame_width_pix, frame_height_pix, SDL_SWSURFACE|SDL_SRCALPHA, true);
 
-	// Disable per pixel alpha on the source surface
+        // Disable per pixel alpha on the source surface
     // in order to properly copy the alpha chanel to the destination suface
-	// see the SDL_SetAlpha man page for more infos (RGBA->RGBA without SDL_SRCALPHA)
-	other.frames[f].surface.SetAlpha( 0, 0);
-	new_surf.Blit( other.frames[f].surface, NULL, NULL);
+        // see the SDL_SetAlpha man page for more infos (RGBA->RGBA without SDL_SRCALPHA)
+        other.frames[f].surface.SetAlpha( 0, 0);
+        new_surf.Blit( other.frames[f].surface, NULL, NULL);
 
-	// re-enable the per pixel alpha in the
-	other.frames[f].surface.SetAlpha( SDL_SRCALPHA, 0);
+        // re-enable the per pixel alpha in the
+        other.frames[f].surface.SetAlpha( SDL_SRCALPHA, 0);
     frames.push_back( SpriteFrame(new_surf,other.frames[f].delay));
   }
 
@@ -129,58 +129,63 @@ SpriteCache::SpriteCache(Sprite &p_sprite, const SpriteCache &other)  :
 }
 #endif
 
-void SpriteCache::EnableRotationCache(std::vector<SpriteFrame> &sprite_frames, unsigned int cache_size){
+void SpriteCache::EnableRotationCache(std::vector<SpriteFrame> &sprite_frames, unsigned int cache_size)
+{
   //For each frame, we pre-render 'cache_size' rotated surface
   //At runtime the prerender Surface with the nearest angle to what is asked is displayed
-  assert(1 < cache_size and cache_size <= 360);
-  assert(!have_lastframe_cache);
-  assert(!have_flipping_cache); //Always compute rotation cache before flipping cache!
-  assert(!have_rotation_cache);
+  ASSERT(1 < cache_size && cache_size <= 360);
+  ASSERT(!have_lastframe_cache);
+  ASSERT(!have_flipping_cache); //Always compute rotation cache before flipping cache!
+  ASSERT(!have_rotation_cache);
   have_rotation_cache = true;
 
   if (frames.empty())
     frames.resize( sprite_frames.size() );
-  assert( frames.size() == sprite_frames.size() );
+  ASSERT( frames.size() == sprite_frames.size() );
   rotation_cache_size = cache_size;
 
   for ( unsigned int f = 0 ; f < frames.size() ; f++)
   {
-    frames[f].CreateRotationCache(sprite_frames[f].surface, cache_size);
+    frames[f].CreateRotationCache(sprite_frames[f].surface, cache_size, sprite.IsAntialiased());
   }
 }
 
-void SpriteCache::EnableFlippingCache(std::vector<SpriteFrame> &sprite_frames){
+void SpriteCache::EnableFlippingCache(std::vector<SpriteFrame> &sprite_frames)
+{
   //For each frame, we pre-render the flipped frame
-  assert(!have_flipping_cache);
-  assert(!have_lastframe_cache);
+  ASSERT(!have_flipping_cache);
+  ASSERT(!have_lastframe_cache);
 
   if (frames.empty())
     frames.resize( sprite_frames.size() );
-  assert( frames.size() == sprite_frames.size() );
+  ASSERT( frames.size() == sprite_frames.size() );
 
   have_flipping_cache = true;
 
   for ( unsigned int f = 0 ; f < frames.size() ; f++)
-    frames[f].CreateFlippingCache(sprite_frames[f].surface);
+    frames[f].CreateFlippingCache(sprite_frames[f].surface, sprite.IsAntialiased());
 }
 
-void SpriteCache::EnableLastFrameCache(){
+void SpriteCache::EnableLastFrameCache()
+{
   //The result of the last call to SDLgfx is kept in memory
   //to display it again if rotation / scale / alpha didn't changed
-  assert(!have_rotation_cache);
-  assert(!have_flipping_cache);
+  ASSERT(!have_rotation_cache);
+  ASSERT(!have_flipping_cache);
   have_lastframe_cache = true;
 }
 
-void SpriteCache::DisableLastFrameCache(){
+void SpriteCache::DisableLastFrameCache()
+{
   //The result of the last call to SDLgfx is kept in memory
   //to display it again if rotation / scale / alpha didn't changed
-  assert(!have_rotation_cache);
-  assert(!have_flipping_cache);
+  ASSERT(!have_rotation_cache);
+  ASSERT(!have_flipping_cache);
   have_lastframe_cache = false;
 }
 
-void SpriteCache::InvalidLastFrame(){
+void SpriteCache::InvalidLastFrame()
+{
   //Free lastframe_cache if the next frame to be displayed
   //is not the same as the last one.
   if(!have_lastframe_cache)
