@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,7 +27,8 @@
 
 #include <vector>
 #include "include/base.h"
-#include "spriteframe.h"
+#include "graphic/spriteframe.h"
+#include "graphic/surface.h"
 
 class Sprite;
 
@@ -43,8 +44,8 @@ public:
   Surface GetSurfaceForAngle(double angle) const;
 
   SpriteFrameCache();
-  void CreateRotationCache(Surface &surface, unsigned int cache_size);
-  void CreateFlippingCache(Surface &surface);
+  void CreateRotationCache(Surface &surface, unsigned int cache_size, bool smooth);
+  void CreateFlippingCache(Surface &surface, bool smooth);
 };
 
 class SpriteCache
