@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,31 +30,37 @@ class Text
   Surface surf;
   Surface background; //shadow or outline or nothing;
   std::string txt;
-  Font* font;
   Color color;
   bool shadowed;
+  bool dummy;
   uint bg_offset;
   uint max_width;
 
-  void Render();
+  Font::font_size_t font_size;
+  Font::font_style_t font_style;
+
+  virtual void Render();
   void RenderMultiLines();
 public:
-  Text(const std::string &new_txt, const Color& new_color = white_color, 
-       Font* new_font = NULL, bool shadowed = true);
-  ~Text();
+  Text(const std::string &new_txt,
+       const Color& new_color = white_color,
+       Font::font_size_t fsize = Font::FONT_SMALL,
+       Font::font_style_t fstyle = Font::FONT_NORMAL,
+       bool shadowed = true,
+       bool dummy = false);
+  virtual ~Text();
 
   //Draw method using windows coordinates
-  void DrawCenter(int x, int y) const;
   void DrawCenter(const Point2i &position) const;
-  void DrawTopLeft(int x, int y) const;
   void DrawTopLeft(const Point2i &position) const;
-  void DrawTopRight(int x, int y) const;
-  void DrawCenterTop(int x, int y) const;
+  void DrawTopRight(const Point2i &position) const;
+  void DrawCenterTop(const Point2i &position) const;
+
+  //Draw text cursor only (text_pos = position for DrawTopLeft)
+  void DrawCursor(const Point2i &text_pos, std::string::size_type cursor_pos) const;
 
   //Draw method using map coordinates
-  void DrawCenterOnMap(int x, int y) const;
-  void DrawTopLeftOnMap(int x, int y) const;
-  void DrawCenterTopOnMap(int x, int y) const;
+  void DrawCenterTopOnMap(const Point2i &position) const;
 
   void Set(const std::string &new_txt);
   const std::string& GetText() const;
@@ -64,17 +70,10 @@ public:
   int GetHeight() const;
 };
 
-void DrawTmpBoxText(Font& font, 
-		    Point2i pos,
-		    const std::string& txt, uint space=3,
-		    const Color& boxColor = defaultColorBox,
-		    const Color& rectColor = defaultColorRect);
-
-/* void DrawTmpBoxTextWithReturns(Font &font, */
-/* 			       const Point2i &position, */
-/* 			       const std::string &txt, uint space=3, */
-/* 			       Color boxColor = defaultColorBox, */
-/* 			       Color rectColor = defaultColorRect); */
-
+void DrawTmpBoxText(Font& font,
+                    Point2i pos,
+                    const std::string& txt, uint space=3,
+                    const Color& boxColor = defaultColorBox,
+                    const Color& rectColor = defaultColorRect);
 
 #endif
