@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,60 +17,78 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  *****************************************************************************/
 
-#include "video.h"
-#include <string>
+#include <algorithm>
 #include <iostream>
-#include <SDL_endian.h>
 #include <SDL_image.h>
-#include "../game/config.h"
-#include "../tool/error.h"
-#include "../tool/i18n.h"
-#include "../include/app.h"
-#include "../include/constant.h"
-#include "../map/camera.h"
+#include "game/config.h"
+#include "graphic/video.h"
+#include "include/app.h"
+#include "include/constant.h"
+#include "map/camera.h"
+#include "tool/i18n.h"
+
 
 Video::Video(){
   SetMaxFps (50);
   fullscreen = false;
   SDLReady = false;
+  icon = NULL;
+
+  InitSDL();
+
+  window.SetSurface( NULL , false );
+  window.SetAutoFree( false );
+
+  Config * config = Config::GetInstance();
+  SetConfig((int)(config->GetVideoWidth()),
+            (int)(config->GetVideoHeight()),
+            config->IsVideoFullScreen());
+
+  SetMaxFps(config->GetMaxFps());
+
+  if( window.IsNull() ) {
+    Error(Format("Unable to initialize SDL window: %s", SDL_GetError()));
+    exit (1);
+  }
+
+  SetWindowCaption( std::string("Wormux ") + Constants::WORMUX_VERSION );
+  SetWindowIcon( config->GetDataDir() + "wormux_32x32.xpm" );
+
+  ComputeAvailableConfigs();
 }
 
 Video::~Video(){
+  if (icon)
+    SDL_FreeSurface(icon);
   if( SDLReady )
     SDL_Quit();
+  SDLReady = false;
 }
 
 void Video::SetMaxFps(uint max_fps){
   m_max_fps = max_fps;
   if (0 < m_max_fps)
-    m_sleep_max_fps = 1000/m_max_fps;
+    m_max_delay = 1000/m_max_fps;
   else
-    m_sleep_max_fps = 0;
+    m_max_delay = 0;
 }
 
-uint Video::GetMaxFps(){
-  return m_max_fps;
-}
-
-uint Video::GetSleepMaxFps(){
-  return m_sleep_max_fps;
-}
-
-bool Video::IsFullScreen() const{
-  return fullscreen;
-}
-
-bool CompareConfigs(const Point2i& a, const Point2i& b)
+static bool CompareConfigs(const Point2i& a, const Point2i& b)
 {
-  return  (a.x >= b.x) && (a.y >= b.y);
+  return  (a.x < b.x) || ((a.x == b.x) && (a.y < b.y));
+}
+
+void Video::AddConfigIfAbsent(int w, int h)
+{
+  Point2i p(w, h);
+
+  if ( !CompareConfigs((*available_configs.begin()), p) &&
+       find(available_configs.begin(), available_configs.end(), p) == available_configs.end() )
+    available_configs.push_back(p);
 }
 
 void Video::ComputeAvailableConfigs()
 {
-  // Add the current resolution
-  available_configs.push_back(Point2i(AppWormux::GetInstance()->video.window.GetWidth(),
-                                      AppWormux::GetInstance()->video.window.GetHeight()));
-
   //Generate video mode list
   SDL_Rect **modes;
 
@@ -87,27 +105,20 @@ void Video::ComputeAvailableConfigs()
     }
   }
 
+  // Add the current resolution
+  AddConfigIfAbsent(window.GetWidth(), window.GetHeight());
+
+  // If biggest resolution is big enough, we propose standard resolutions
+  // such as 1600x1200, 1280x1024, 1024x768, 800x600.
+  for(std::list<Point2i>::iterator res = Config::GetInstance()->GetResolutionAvailable().begin();
+      res != Config::GetInstance()->GetResolutionAvailable().end();
+      res++) {
+    AddConfigIfAbsent((*res).GetX(), (*res).GetY());
+  }
+
   // Sort the list
   available_configs.sort(CompareConfigs);
 
-  // If biggest resolution is big enough, we propose standard resolution such as
-  // 800x600, 1024x768, 1280x1024, 1600x1200
-  Point2i a(800, 600);
-  if ( CompareConfigs((*available_configs.begin()), a))
-    available_configs.push_back(a);
-  Point2i b(1024, 768);
-  if ( CompareConfigs((*available_configs.begin()), b))
-    available_configs.push_back(b);
-  Point2i c(1280, 1024);
-  if ( CompareConfigs((*available_configs.begin()), c))
-    available_configs.push_back(c);
-  Point2i d(1600, 1200);
-  if ( CompareConfigs((*available_configs.begin()), d))
-    available_configs.push_back(d);
-
-  // Sort the list again...
-  available_configs.sort(CompareConfigs);
-
   // Remove double items
   std::list<Point2i>::iterator prev = available_configs.begin(),
     it = available_configs.begin() ,
@@ -121,80 +132,67 @@ void Video::ComputeAvailableConfigs()
   }
 }
 
-std::list<Point2i>& Video::GetAvailableConfigs()
-{
-  return available_configs;
-}
+bool Video::SetConfig(const int width, const int height, const bool _fullscreen){
+  int flag = (_fullscreen) ? SDL_FULLSCREEN : 0;
+  bool window_was_null = window.IsNull();
 
-bool Video::SetConfig(int width, int height, bool _fullscreen){
-  // initialize the main window
+
+  // update the main window if needed
   if( window.IsNull() ||
      (width != window.GetWidth() ||
-      height != window.GetHeight() ) ){
+      height != window.GetHeight() ) ||
+      fullscreen != _fullscreen){
 
     window.SetSurface( SDL_SetVideoMode(width, height, 32,
-                       SDL_HWSURFACE | SDL_HWACCEL | SDL_DOUBLEBUF ), false );
+                       SDL_HWSURFACE | SDL_HWACCEL | SDL_DOUBLEBUF | flag), false );
 
     if( window.IsNull() ) {
-      window.SetSurface( SDL_SetVideoMode(width, height, 32, SDL_SWSURFACE) );
+      window.SetSurface( SDL_SetVideoMode(width, height, 32, SDL_SWSURFACE | flag) );
       std::cerr << "WARNING: Video not using hardware acceleration!" << std::endl;
     }
 
     if( window.IsNull() )
       return false;
-    fullscreen = false;
-  }
 
-  if(fullscreen != _fullscreen) {
-    SDL_WM_ToggleFullScreen( window.GetSurface() );
-    fullscreen = !fullscreen;
-  }
+    fullscreen = _fullscreen;
+    Camera::GetInstance()->SetSize(width, height);
 
-  camera.SetSize(width, height);
+    // refresh all the map when switching to higher resolution
+    if (!window_was_null)
+      AppWormux::GetInstance()->RefreshDisplay();
+  }
 
   return true;
 }
 
 void Video::ToggleFullscreen()
 {
+#ifndef WIN32
   SDL_WM_ToggleFullScreen( window.GetSurface() );
   fullscreen = !fullscreen;
+#else
+  SetConfig(window.GetWidth(), window.GetHeight(), !fullscreen);
+  AppWormux::GetInstance()->RefreshDisplay();
+#endif
 }
 
-void Video::InitWindow(){
-  InitSDL();
-
-  window.SetSurface( NULL , false );
-  window.SetAutoFree( false );
-
-  Config * config = Config::GetInstance();
-  SetConfig(config->tmp.video.width,
-            config->tmp.video.height,
-            config->tmp.video.fullscreen);
-
-  if( window.IsNull() )
-    Error( "Unable to initialize SDL window.");
-
-  SetWindowCaption( std::string("Wormux ") + Constants::VERSION );
-  SetWindowIcon( config->GetDataDir() + PATH_SEPARATOR + "wormux-32.xpm" );
-
-  ComputeAvailableConfigs();
-}
-
-void Video::SetWindowCaption(std::string caption){
+void Video::SetWindowCaption(const std::string& caption) const {
   SDL_WM_SetCaption( caption.c_str(), NULL );
 }
 
-void Video::SetWindowIcon(std::string filename){
-  SDL_WM_SetIcon( IMG_Load(filename.c_str()), NULL );
+void Video::SetWindowIcon(const std::string& filename) {
+  icon = IMG_Load(filename.c_str());
+  SDL_WM_SetIcon( icon, NULL );
 }
 
 void Video::InitSDL(){
   if( SDLReady )
     return;
 
-  if( SDL_Init(SDL_INIT_TIMER | SDL_INIT_VIDEO) < 0 )
-    Error( Format( _("Unable to initialize SDL library: %s"), SDL_GetError() ) );
+  if( SDL_Init(SDL_INIT_TIMER | SDL_INIT_VIDEO) < 0 ) {
+    Error(Format("Unable to initialize SDL library: %s", SDL_GetError()));
+    exit (1);
+  }
 
   SDL_EnableUNICODE(1);
   SDLReady = true;
