@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,33 +19,20 @@
  * Simple button
  *****************************************************************************/
 
-#include "button.h"
-#include "../tool/resource_manager.h"
-#include "../graphic/sprite.h"
-#include "../include/app.h"
+#include "gui/button.h"
+#include "include/app.h"
+#include "graphic/sprite.h"
+#include "graphic/video.h"
+#include "tool/resource_manager.h"
 
-Button::Button (const Rectanglei &rect, const Profile *res_profile,
-		const std::string& resource_id, bool _img_scale) : Widget(rect)
+
+Button::Button (const Profile *res_profile,
+                const std::string& resource_id, bool _img_scale):
+  img_scale(_img_scale),
+  image(resource_manager.LoadSprite(res_profile,resource_id))
 {
-  image = resource_manager.LoadSprite(res_profile,resource_id);
-  image->cache.EnableLastFrameCache();
-
-  // image scalling or not
-  img_scale = _img_scale;
-  
-  if (img_scale)
-    image->ScaleSize(rect.GetSize());
-}
-
-Button::Button (const Point2i &m_position, const Profile *res_profile, 
-		const std::string& resource_id, bool _img_scale)
-{
-  image = resource_manager.LoadSprite(res_profile, resource_id);
-  position = m_position;
+  position = Point2i(-1, -1);
   size = image->GetSize();
-
-  // image scalling on resize
-  img_scale = _img_scale;
 }
 
 Button::~Button()
@@ -53,9 +40,16 @@ Button::~Button()
   delete image;
 }
 
-void Button::Draw(const Point2i &mousePosition, Surface& surf) const
+void Button::Draw(const Point2i &/*mousePosition*/) const
 {
-  uint frame = Contains(mousePosition)?1:0;
+  Surface& surf = AppWormux::GetInstance()->video->window;
+
+  uint frame = (IsHighlighted());
+
+  // Check that there are enough frames in the image...
+  if (image->GetFrameCount() <= frame) {
+    frame = 0;
+  }
 
   image->SetCurrentFrame(frame);
 
@@ -73,10 +67,9 @@ void Button::Draw(const Point2i &mousePosition, Surface& surf) const
   }
 }
 
-void Button::SetSizePosition(const Rectanglei &rect)
+void Button::Pack()
 {
-  StdSetSizePosition(rect);
-
   if (img_scale)
     image->ScaleSize(size);
 }
+
