@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,20 +23,29 @@
 #define BUTTON_TEXT_H
 
 #include "button.h"
-#include "../graphic/text.h"
+#include "graphic/font.h"
+
+class Text;
 
 class ButtonText : public Button
 {
 private:
+  /* If you need this, implement it (correctly)*/
+  ButtonText(const ButtonText&);
+  ButtonText operator=(const ButtonText&);
+  /*********************************************/
+
   Text *text;
-   
+
 public:
-  ButtonText(Point2i position,
-	      const Profile *res_profile, const std::string& resource_id,
-	      const std::string &new_text, Font *font);
+  ButtonText(const Profile *res_profile,
+             const std::string& resource_id,
+             const std::string &new_text,
+             Font::font_size_t font_size,
+             Font::font_style_t font_style);
   ~ButtonText();
 
-  void Draw(const Point2i &mousePosition, Surface& surf) const; 
+  void Draw(const Point2i &mousePosition) const;
 };
 
 #endif
