@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,14 +22,15 @@
 #ifndef CONTAINER_WIDGET_H
 #define CONTAINER_WIDGET_H
 
-#include "../graphic/surface.h"
+#include "tool/rectangle.h"
+
+class Surface;
 
 class Container
 {
  public:
   virtual ~Container() {};
-  virtual void Redraw(const Rectanglei& rect,
-		      Surface& surf) = 0;
+  virtual void RedrawBackground(const Rectanglei& rect) = 0;
 };
 
 #endif
