@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,13 +24,15 @@
 
 #include "widget.h"
 
+class Surface;
+
 class NullWidget : public Widget
 {
  public:
-  NullWidget(const Rectanglei &rect);
-  ~NullWidget();
-  void Draw(const Point2i &mousePosition, Surface& surf) const;
-  void SetSizePosition(const Rectanglei &rect);
+  NullWidget(const Rectanglei&) {};
+  virtual ~NullWidget() {};
+  virtual void Draw(const Point2i&) const {};
+  virtual void Pack() {};
 };
 
 #endif
