@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,11 +19,12 @@
  * Progress bar for GUI.
  *****************************************************************************/
 
-#include "progress_bar.h"
+#include "gui/progress_bar.h"
 #include <SDL.h>
-#include "../include/app.h"
-#include "../map/map.h"
-#include "../tool/math_tools.h"
+#include "graphic/video.h"
+#include "include/app.h"
+#include "map/map.h"
+#include "tool/math_tools.h"
 
 ProgressBar::ProgressBar(){
    border_color.SetColor(0, 0, 0, 255);
@@ -34,21 +35,9 @@ ProgressBar::ProgressBar(){
    m_use_ref_val = false;
 }
 
-void ProgressBar::SetBorderColor(Color color){
-   border_color = color;
-}
-
-void ProgressBar::SetBackgroundColor(Color color){
-   background_color = color;
-}
-
-void ProgressBar::SetValueColor(Color color){
-   value_color = color;
-}
-
 void ProgressBar::InitPos (uint px, uint py, uint plarg, uint phaut){
-  assert (3 <= plarg);
-  assert (3 <= phaut);
+  ASSERT (3 <= plarg);
+  ASSERT (3 <= phaut);
   x = px;
   y = py;
   larg = plarg;
@@ -65,33 +54,29 @@ void ProgressBar::InitPos (uint px, uint py, uint plarg, uint phaut){
  */
 void ProgressBar::InitVal (long pval, long pmin, long pmax,
     enum orientation porientation){
-  assert (pmin != pmax);
-  assert (pmin < pmax);
+  ASSERT (pmin != pmax);
+  ASSERT (pmin < pmax);
   val = pval;
   min = pmin;
   max = pmax;
   orientation = porientation;
-  val_barre = CalculeValBarre(val);
+  val_barre = ComputeBarValue(val);
 }
 
 void ProgressBar::UpdateValue (long pval){
-  val = CalculeVal(pval);
-  val_barre = CalculeValBarre(val);
+  val = ComputeValue(pval);
+  val_barre = ComputeBarValue(val);
 }
 
-uint ProgressBar::CalculeVal (long val) const{
-  return BorneLong(val, min, max);
+long ProgressBar::ComputeValue (long pval) const{
+  return InRange_Long(pval, min, max);
 }
 
-uint ProgressBar::CalculeValBarre (long val) const{
+uint ProgressBar::ComputeBarValue (long val) const{
   if(orientation == PROG_BAR_HORIZONTAL)
-    return ( CalculeVal(val) -min)*(larg-2)/(max-min);
+    return ( ComputeValue(val) -min)*(larg-2)/(max-min);
   else
-    return ( CalculeVal(val) -min)*(haut-2)/(max-min);
-}
-
-void ProgressBar::Draw() const{
-  DrawXY( Point2i(x, y) );
+    return ( ComputeValue(val) -min)*(haut-2)/(max-min);
 }
 
 // TODO pass a Surface as parameter
@@ -107,7 +92,7 @@ void ProgressBar::DrawXY(const Point2i &pos) const{
 
   // Valeur
   if (m_use_ref_val) {
-    int ref = CalculeValBarre (m_ref_val);
+    int ref = ComputeBarValue (m_ref_val);
     if (val < m_ref_val) { // FIXME hum, this seems buggy
       begin = 1+val_barre;
       end = 1+ref;
@@ -129,7 +114,7 @@ void ProgressBar::DrawXY(const Point2i &pos) const{
   image.FillRect(r_value, value_color);
 
   if (m_use_ref_val) {
-    int ref = CalculeValBarre (m_ref_val);
+    int ref = ComputeBarValue (m_ref_val);
     Rectanglei r_ref;
     if(orientation == PROG_BAR_HORIZONTAL)
        r_ref = Rectanglei(1 + ref, 1, 1, haut - 2);
@@ -139,8 +124,8 @@ void ProgressBar::DrawXY(const Point2i &pos) const{
   }
 
   // Marqueurs
-  marqueur_it_const it=marqueur.begin(), fin=marqueur.end();
-  for (; it != fin; ++it)
+  marqueur_it_const it=marqueur.begin(), it_end = marqueur.end();
+  for (; it != it_end; ++it)
   {
     Rectanglei r_marq;
     if(orientation == PROG_BAR_HORIZONTAL)
@@ -150,7 +135,7 @@ void ProgressBar::DrawXY(const Point2i &pos) const{
     image.FillRect( r_marq, it->color);
   }
   Rectanglei dst(pos.x, pos.y, larg, haut);
-  AppWormux::GetInstance()->video.window.Blit(image, pos);
+  AppWormux::GetInstance()->video->window.Blit(image, pos);
 
   world.ToRedrawOnScreen(dst);
 }
@@ -159,19 +144,15 @@ void ProgressBar::DrawXY(const Point2i &pos) const{
 ProgressBar::marqueur_it ProgressBar::AddTag (long val, const Color& color){
   marqueur_t m;
 
-  m.val = CalculeValBarre (val);
+  m.val = ComputeBarValue(val);
   m.color = color;
   marqueur.push_back (m);
 
   return --marqueur.end();
 }
 
-void ProgressBar::ResetTag(){
-  marqueur.clear();
-}
-
 void ProgressBar::SetReferenceValue (bool use, long value){
   m_use_ref_val = use;
-  m_ref_val = CalculeVal(value);
+  m_ref_val = ComputeValue(value);
 }
 
