@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,11 +22,10 @@
 #ifndef PROGRESS_BAR_H
 #define PROGRESS_BAR_H
 
-#include <SDL.h>
 #include <list>
-#include "../include/base.h"
-#include "../graphic/color.h"
-#include "../graphic/surface.h"
+#include "include/base.h"
+#include "graphic/color.h"
+#include "graphic/surface.h"
 
 class ProgressBar
 {
@@ -46,18 +45,18 @@ private:
   uint val_barre; // current value in the progress bar
   enum orientation orientation;
 
-  uint CalculeVal (long val) const;
-  uint CalculeValBarre (long val) const;
+  long ComputeValue (long val) const;
+  uint ComputeBarValue (long val) const;
 
   typedef struct s_marqueur_t{
-	  Color color;
-	  uint val;
+    Color color;
+    uint val;
   } marqueur_t;
 
  public:
-  void SetBorderColor(Color color);
-  void SetBackgroundColor(Color color);
-  void SetValueColor(Color color);
+  void SetBorderColor(const Color& color) { border_color = color; };
+  void SetBackgroundColor(const Color& color) { background_color = color; };
+  void SetValueColor(const Color& color) { value_color = color; };
  private:
   typedef std::list<marqueur_t>::iterator marqueur_it;
   typedef std::list<marqueur_t>::const_iterator marqueur_it_const;
@@ -65,8 +64,13 @@ private:
 
 public:
   ProgressBar();
+  virtual ~ProgressBar() {};
 
-  // Actualisation de la valeur
+  int GetCurrentValue() { return val; };
+  int GetMinValue() { return min; };
+  int GetMaxValue() { return max; };
+
+  // Update current value
   void UpdateValue (long val);
 
   // Initialise la position
@@ -80,7 +84,7 @@ public:
   void SetReferenceValue (bool use, long value=0);
 
   // Draw la barre de progresssion
-  void Draw() const;
+  void Draw() const {  DrawXY( Point2i(x, y) ); };
 
   // Draw the progress bar
   void DrawXY(const Point2i &pos) const;
@@ -94,7 +98,7 @@ public:
 
   // add/remove value tag
   marqueur_it AddTag (long val, const Color& coul);
-  void ResetTag();
+  void ResetTag() { marqueur.clear(); };
 };
 
 #endif
