@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,36 +22,35 @@
 #ifndef APP_WORMUX_H
 #define APP_WORMUX_H
 
-#include <SDL.h>
 #include <string>
 #include "base.h"
-#include "../game/config.h"
-#include "../graphic/video.h"
+
+class Video;
+class Menu;
 
 class AppWormux
 {
 public:
-  Video video;
+  Video *video;
 
 private:
-  int x, y;
-  std::string windows_title;
-
+  Menu *menu;
   static AppWormux * singleton;
 
 private:
-  void Init(int, char**);
   void InitWindow();
   void DisplayLoadingPicture();
-  void InitFonts();
-  void End();
-  void DisplayWelcomeMessage();
+  void End() const;
+  void DisplayWelcomeMessage() const;
   AppWormux();
 
 public:
+  void SetCurrentMenu(Menu *menu);
+  void RefreshDisplay();
   static AppWormux * GetInstance();
+  ~AppWormux();
 
-  int main( int argc, char ** argv );
+  int Main(void);
 };
 
 #endif
