@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,17 +19,14 @@
  * Arrow on top of the active character
  *****************************************************************************/
 
-#include "cursor.h"
-#include <SDL.h>
-#include "../game/game_loop.h"
-#include "../game/time.h"
-#include "../graphic/effects.h"
-#include "../include/app.h"
-#include "../map/camera.h"
-#include "../object/physical_obj.h"
-#include "../team/teams_list.h" // ActiveCharacter()
-#include "../tool/point.h"
-#include "../tool/resource_manager.h"
+#include "interface/cursor.h"
+#include "character/character.h"
+#include "game/time.h"
+#include "graphic/effects.h"
+#include "graphic/sprite.h"
+#include "map/camera.h"
+#include "team/teams_list.h" // ActiveCharacter()
+#include "tool/resource_manager.h"
 
 const uint show_hide_time = 200; //time to show and hide the arrow
 const uint y_min = 20; //number of pixels between the bottom of the arrow and the top of the sprite
@@ -37,23 +34,14 @@ const uint y_max = 90; //number of pixels between the bottom of the arrow and th
                         //when the arrow is at the top of its movement
 const uint rebound_time = 1000; //Duration of a full rebound
 
-CharacterCursor * CharacterCursor::singleton = NULL;
-
-CharacterCursor * CharacterCursor::GetInstance() {
-  if (singleton == NULL) {
-    singleton = new CharacterCursor();
-  }
-  return singleton;
-}
-
 CharacterCursor::CharacterCursor()
 {
-  actif = false;
+  visible = false;
   want_hide = false;
   time_begin_anim = 0;
   last_update = 0;
   image = NULL;
-  dy = 0;  
+  dy = 0;
 
   Profile *res = resource_manager.LoadXMLProfile( "graphism.xml", false);
   image = resource_manager.LoadSprite( res, "gfx/curseur");
@@ -62,21 +50,21 @@ CharacterCursor::CharacterCursor()
 
 CharacterCursor::~CharacterCursor()
 {
-  if(image) delete image;
+  if (image)
+    delete image;
 }
 
-// Dessine le curseur
+// Draw cursor
 void CharacterCursor::Draw()
 {
   if (!IsDisplayed()) return;
-  if (obj_designe == NULL) return;
-  if (obj_designe -> IsGhost()) return;
+  if (ActiveCharacter().IsGhost()) return;
+
+  // Draw cursor arround character
+  Point2i center = ActiveCharacter().GetCenter();
+  uint x = center.x - image->GetWidth()/2;
+  uint y = ActiveCharacter().GetY() - image->GetHeight() - y_min;
 
-  // Dessine le curseur autour du ver
-  Point2i centre = obj_designe->GetCenter();
-  uint x = centre.x - image->GetWidth()/2;
-  uint y = obj_designe->GetY() - image->GetHeight() - y_min;
-  
   image->Draw( Point2i(x, y+dy) );
 }
 
@@ -89,9 +77,9 @@ void CharacterCursor::Refresh()
   Time * global_time = Time::GetInstance();
 
   //The arrow is appearing:
-  if( actif && global_time->Read() < time_begin_anim + show_hide_time )
+  if( visible && global_time->Read() < time_begin_anim + show_hide_time )
   {
-    dy = (int)((camera.GetPosition().y - ActiveCharacter().GetY()) * (1.0 - (global_time->Read() - time_begin_anim) / (float)show_hide_time));
+    dy = (int)((Camera::GetInstance()->GetPosition().y - ActiveCharacter().GetY()) * (1.0 - (global_time->Read() - time_begin_anim) / (float)show_hide_time));
     return;
   }
 
@@ -99,23 +87,23 @@ void CharacterCursor::Refresh()
   if(want_hide)
   {
     if( ((global_time->Read() - (time_begin_anim + show_hide_time)) % rebound_time < rebound_time / 2)
-    &&  ((last_update                - (time_begin_anim + show_hide_time)) % rebound_time > rebound_time / 2))
+    &&  ((last_update - (time_begin_anim + show_hide_time)) % rebound_time > rebound_time / 2))
     {
       //We are at the end of the rebound
-      actif = false;
+      visible = false;
       time_begin_anim = global_time->Read();
     }
   }
 
   //The arrow is disappearing:
-  if( !actif && global_time->Read() < time_begin_anim + show_hide_time )
+  if( !visible && global_time->Read() < time_begin_anim + show_hide_time )
   {
-    dy = (int)((camera.GetPosition().y - ActiveCharacter().GetY()) * ((global_time->Read() - time_begin_anim) / (float)show_hide_time));
+    dy = (int)((Camera::GetInstance()->GetPosition().y - ActiveCharacter().GetY()) * ((global_time->Read() - time_begin_anim) / (float)show_hide_time));
     return;
   }
 
   //The arrow is rebounding:
-  Rebound(image, dy, time_begin_anim + show_hide_time, rebound_time, -y_max - (-y_min));
+  Rebound(image, dy, time_begin_anim + show_hide_time, rebound_time, (int)y_min - (int)y_max);
 
   last_update = global_time->Read();
 }
@@ -123,33 +111,27 @@ void CharacterCursor::Refresh()
 // Hide the cursor
 void CharacterCursor::Hide()
 {
-  if(!actif) return;
+  if (!visible) return;
   want_hide = true;
 }
 
 void CharacterCursor::Reset()
 {
-  actif = false;
+  visible = false;
   want_hide = false;
-  obj_designe = NULL;
 }
 
 void CharacterCursor::FollowActiveCharacter()
 {
-  PointeObj(&ActiveCharacter());
-}
-
-void CharacterCursor::PointeObj (PhysicalObj *obj)
-{
-  if(actif && obj==obj_designe)
+  if (visible)
     return;
-  obj_designe = obj;
-  actif = true;
+
+  visible = true;
   want_hide = false;
   time_begin_anim = Time::GetInstance()->Read();
 }
 
 // Are we displaying the arrow on the screen ?
 bool CharacterCursor::IsDisplayed() const {
-  return actif || (Time::GetInstance()->Read() < time_begin_anim + show_hide_time);
+  return visible || (Time::GetInstance()->Read() < time_begin_anim + show_hide_time);
 }
