@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,49 +22,45 @@
 #ifndef CURSOR_H
 #define CURSOR_H
 //-----------------------------------------------------------------------------
-#include "../graphic/sprite.h"
-#include "../object/physical_obj.h"
-#include "../include/base.h"
+#include "include/base.h"
+#include "include/singleton.h"
 //-----------------------------------------------------------------------------
 
-class CharacterCursor
+class Sprite;
+
+class CharacterCursor : public Singleton<CharacterCursor>
 {
 public:
    Sprite *image;
 
 private:
+  /* If you need this, implement it (correctly)*/
+  CharacterCursor(const CharacterCursor&);
+  const CharacterCursor& operator=(const CharacterCursor&);
+  /*********************************************/
+
   uint time_begin_anim;
   uint last_update;
-  PhysicalObj *obj_designe;
   int dy;
-  bool actif;
+  bool visible;
   bool want_hide;
 
-  static CharacterCursor * singleton;
+  bool IsDisplayed() const;
 
 public:
-  static CharacterCursor * GetInstance();
-
   void Reset();
   void Draw();
   void Refresh();
 
-  // Pointe un objet
-  void PointeObj (PhysicalObj *obj);
-
-  // Pointe un objet
   void FollowActiveCharacter ();
 
   // Hide the cursor
   void Hide();
 
-  
-
-private:
+protected:
+  friend class Singleton<CharacterCursor>;
   CharacterCursor();
   ~CharacterCursor();
-
-  bool IsDisplayed() const;
 };
 
 //-----------------------------------------------------------------------------
