@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,28 +22,38 @@
 #ifndef INTERFACE_H
 #define INTERFACE_H
 #include <vector>
+#include "include/base.h"
+#include "include/singleton.h"
 #include "weapon_menu.h"
-#include "../graphic/surface.h"
-#include "../graphic/sprite.h"
-#include "../gui/progress_bar.h"
-#include "../include/base.h"
-#include "../character/character.h"
-#include "../team/team.h"
+#include "gui/energy_bar.h"
+#include "gui/energy_bar.h"
+#include "gui/progress_bar.h"
+
+// Forward declarations
+class Character;
+class Team;
+class Text;
+class Polygon;
+class Weapon;
 
 #ifdef WIN32
 #undef interface
 #endif
 
-class Interface
+class Interface : public Singleton<Interface>
 {
-
 public:
   Character *character_under_cursor;
-  Weapon* weapon_under_cursor;
+  Weapon *weapon_under_cursor;
   WeaponsMenu weapons_menu;
-  Team * tmp_team;
+  Team *tmp_team;
 
  private:
+   /* If you need this, implement it (correctly)*/
+   Interface(const Interface&);
+   const Interface& operator=(const Interface&);
+   /*********************************************/
+
    // Timers
    Text * global_timer;
    Text * timer;
@@ -64,6 +74,7 @@ public:
    int start_hide_display;
    int start_show_display;
    bool display_timer;
+   bool display_minimap;
    EnergyBar energy_bar;
    ProgressBar wind_bar;
 
@@ -75,15 +86,13 @@ public:
    Surface wind_indicator;
    Point2i bottom_bar_pos;
 
-   static Interface * singleton;
-
- private:
+protected:
+  friend class Singleton<Interface>;
    Interface();
    ~Interface();
 
  public:
-   static Interface * GetInstance();
-   WeaponsMenu & GetWeaponsMenu() { return weapons_menu; };
+   const WeaponsMenu &GetWeaponsMenu() const { return weapons_menu; };
 
    void Reset();
    void Draw();
@@ -95,25 +104,28 @@ public:
    void DrawWindInfo() const;
    void DrawClock(const Point2i &time_pos) const;
    void DrawTimeInfo() const;
+   void DrawMapPreview();
    void DrawSmallInterface() const;
 
    bool IsDisplayed () const { return display; };
    void EnableDisplay(bool _display);
    void Show();
    void Hide();
-   bool IsVisible() const;
+   bool IsVisible() const { return display; };
 
-   int GetWidth() const;
+   int GetWidth() const { return game_menu.GetWidth(); };
    int GetHeight() const;
    int GetMenuHeight() const;
    Point2i GetSize() const;
 
+   void SetCurrentOverflyWeapon(Weapon * weapon) { weapon_under_cursor = weapon; };
    void UpdateTimer(uint utimer);
-   void UpdateWindIndicator(int wind_value);
+   void UpdateWindIndicator(int wind_value) { wind_bar.UpdateValue(wind_value); };
    void EnableDisplayTimer (bool _display) {display_timer = _display;};
+   void ToggleMinimap() { display_minimap = !display_minimap; };
 };
 
-void AbsoluteDraw(const Surface& s, Point2i pos);
+void AbsoluteDraw(const Surface& s, const Point2i& pos);
 void HideGameInterface();
 void ShowGameInterface();
 
