@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,29 +22,26 @@
 #ifndef SKY_H
 #define SKY_H
 
-#include "tile.h"
 #include <list>
-#include "../graphic/surface.h"
-#include "../include/base.h"
-#include "../tool/point.h"
-#include "../tool/rectangle.h"
+#include "graphic/surface.h"
+#include "include/base.h"
+#include "tool/point.h"
+#include "tool/rectangle.h"
 
 class Sky{
 private:
-	Surface image;
-	Point2i lastPos;
-	Point2i tstVect;
-	Point2i margin;
-	void RedrawParticleList(std::list<Rectanglei> &list);
-	void RedrawParticle(const Rectanglei &particle) const;
-	Point2i GetSkyPos() const;
+  Surface image;
+  Point2i last_pos;
+  void RedrawParticleList(std::list<Rectanglei> &list) const;
+  void RedrawParticle(const Rectanglei &particle) const;
+  Point2i GetSkyPos() const;
 
 public:
-	Sky();
-	void Init();
-	void Reset();
-	void Draw();
-	void Free();
+  Sky() {};
+  void Init();
+  void Reset();
+  void Draw(bool redraw_all);
+  void Free();
 };
 
 #endif
