@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,31 +23,43 @@
 #define WATER_H
 
 #include <vector>
-#include "../graphic/surface.h"
-#include "../include/base.h"
+#include "include/base.h"
+#include "graphic/surface.h"
 
 const uint WATER_INITIAL_HEIGHT = 100;
+#define pattern_width 180
 
 class Water
 {
+public:
+  typedef enum {
+    NO_WATER,
+    WATER,
+    LAVA,
+    MAX_WATER_TYPE
+  } Water_type;
+
 private:
-  uint temps_eau;
   int height_mvt;
-  int vague;
-  bool actif;
   double shift1;
-  uint hauteur_eau;
+  uint water_height;
   uint temps_montee;
-  std::vector<int> height;
+  int height[pattern_width];
   Surface surface;
   Surface pattern;
+  Surface bottom;
+  Surface wpattern;
+  Water_type water_type;
+
 public:
   void Init();
   void Reset();
   void Free();
   void Refresh();
   void Draw();
-  bool IsActive();
-  int GetHeight(int x);
+  bool IsActive() const { return water_type != NO_WATER; }
+  int GetHeight(int x) const;
+
+  void Splash(const Point2i& pos) const;
 };
 #endif
