@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,13 +23,20 @@
 #define GAME_MENU_H
 
 #include "menu.h"
-#include "map_selection_box.h"
-#include "teams_selection_box.h"
-#include "../include/base.h"
-#include "../graphic/font.h"
+
+// Forward declarations
+class TeamsSelectionBox;
+class MapSelectionBox;
+class SpinButtonWithPicture;
+class CheckBox;
 
 class GameMenu : public Menu
 {
+  /* If you need this, implement it (correctly)*/
+   GameMenu(const GameMenu&);
+   GameMenu operator=(const GameMenu&);
+   /********************************************/
+
    /* Team controllers */
    TeamsSelectionBox * team_box;
 
@@ -40,17 +47,19 @@ class GameMenu : public Menu
    Box * game_options;
    SpinButtonWithPicture *opt_duration_turn;
    SpinButtonWithPicture *opt_energy_ini;
-   CheckBox *opt_scroll_on_border;
 
    void SaveOptions();
-   void OnClic(const Point2i &mousePosition, int button);
+   void OnClick(const Point2i &mousePosition, int button);
+   void OnClickUp(const Point2i &mousePosition, int button);
    void Draw(const Point2i &mousePosition);
 
-   void __sig_ok();
-   void __sig_cancel();
+   bool signal_ok();
+   bool signal_cancel();
+   void key_left();
+   void key_right();
 
 public:
-   GameMenu(); 
+   GameMenu();
    ~GameMenu();
 };
 
