@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,22 +22,15 @@
 #ifndef MENU_H
 #define MENU_H
 
-#include "../graphic/sprite.h"
-#include "../gui/button.h"
-#include "../gui/list_box.h"
-#include "../gui/list_box_w_label.h"
-#include "../gui/check_box.h"
-#include "../gui/spin_button.h"
-#include "../gui/spin_button_big.h"
-#include "../gui/spin_button_picture.h"
-#include "../gui/box.h"
-#include "../gui/question.h"
-#include "../gui/label.h"
-#include "../gui/null_widget.h"
-#include "../gui/picture_widget.h"
-#include "../gui/picture_text_cbox.h"
-#include "../gui/container.h"
-#include "../gui/text_box.h"
+#include "gui/widget_list.h"
+
+// Forward declarations
+class Button;
+class Label;
+class Box;
+class HBox;
+class Sprite;
+
 
 typedef enum {
   vOkCancel,
@@ -48,39 +41,60 @@ typedef enum {
 
 class Menu : public Container
 {
+  /* if you need this, implement it (correctly)*/
+  Menu(const Menu&);
+  const Menu &operator=(const Menu&);
+  /*********************************************/
+
 public:
    WidgetList widgets;
    const t_action actions;
 
-   Menu(char* bg, t_action actions = vOkCancel); 
+   Menu(const std::string& bg, t_action actions = vOkCancel);
    virtual ~Menu();
 
-   void Run ();
-   virtual void Redraw(const Rectanglei& rect, Surface& surf);
+   void Run(bool skip=false);
+   virtual void RedrawBackground(const Rectanglei& rect);
+   virtual void RedrawMenu();
+
+   void DisplayError(const std::string &msg);
 
 private:
    Sprite *background;
 
-   /* Actions buttons  */
-   HBox *actions_buttons;
-
-   bool BasicOnClic(const Point2i &mousePosition);
+   bool BasicOnClickUp(const Point2i &mousePosition);
 
 protected:
    Button *b_cancel;
    Button *b_ok;
    bool close_menu;
+   /* Actions buttons  */
+   HBox *actions_buttons;
+
+   void play_ok_sound();
+   void play_cancel_sound();
+   void play_error_sound();
+
+   virtual void mouse_ok();
+   virtual void mouse_cancel();
+   virtual void key_ok();
+   virtual void key_cancel();
+   virtual void key_up();
+   virtual void key_down();
+   virtual void key_left();
+   virtual void key_right();
+   virtual bool signal_ok() = 0;
+   virtual bool signal_cancel() = 0;
 
-   virtual void sig_ok();
-   virtual void sig_cancel();
    virtual void DrawBackground();
+   virtual void Draw(const Point2i &mousePosition) = 0;
+
+   // we have released the button
+   virtual void OnClickUp(const Point2i &mousePosition, int button) = 0;
+
+   // we have clicked but still not released the button
+   virtual void OnClick(const Point2i &mousePosition, int button) = 0;
 
-   virtual void key_ok() {};
-   virtual void key_cancel() {};
-   virtual void __sig_ok() = 0;
-   virtual void __sig_cancel() = 0;
-   virtual void Draw(const Point2i &mousePosition) = 0;   
-   virtual void OnClic(const Point2i &mousePosition, int button) = 0;
    void SetActionButtonsXY(int x, int y);
    void Display(const Point2i& mousePosition);
 };
