@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,38 +23,58 @@
 #define OPTIONS_MENU_H
 
 #include "menu.h"
-#include "../include/base.h"
-#include "../graphic/font.h"
+
+class ListBox;
+class CheckBox;
+class ComboBox;
+class SpinButtonWithPicture;
 
 class OptionMenu : public Menu
 {
-  Font * normal_font;
-
 public:
-   OptionMenu(); 
+   OptionMenu();
    ~OptionMenu();
+   static void CheckUpdates();
 
 private:
 
-   /* Graphic options controllers */   
-   ListBox *lbox_video_mode;
+  /* If you need this, implement it (correctly)*/
+   OptionMenu(const OptionMenu&);
+   OptionMenu operator=(const OptionMenu&);
+   /********************************************/
+
+   /* Graphic options controllers */
+   ComboBox *cbox_video_mode;
+   ListBox *lbox_languages;
    CheckBox *opt_display_wind_particles;
    CheckBox *opt_display_energy;
    CheckBox *opt_display_name;
-   CheckBox *full_screen; 
-   SpinButtonBig *opt_max_fps;
+   CheckBox *opt_scroll_on_border;
+   SpinButtonWithPicture * opt_scroll_border_size;
+   CheckBox *full_screen;
+   SpinButtonWithPicture *opt_max_fps;
 
    /* Sound options controllers */
-   ListBox *lbox_sound_freq;
-   CheckBox *opt_music;
-   CheckBox *opt_sound_effects;
+   ComboBox *cbox_sound_freq;
+   uint initial_vol_mus;
+   uint initial_vol_eff;
+   SpinButtonWithPicture *volume_music;
+   SpinButtonWithPicture *volume_effects;
+   CheckBox *music_cbox;
+   CheckBox *effects_cbox;
+
+   /* Misc options controllers */
+   CheckBox *opt_updates;
 
    void SaveOptions();
-   void OnClic(const Point2i &mousePosition, int button);
+   void OnClick(const Point2i &mousePosition, int button);
+   void OnClickUp(const Point2i &mousePosition, int button);
    void Draw(const Point2i &mousePosition);
+   static uint fromVolume(uint vol);
+   static uint toVolume(uint level);
 
-   void __sig_ok();
-   void __sig_cancel();
+   bool signal_ok();
+   bool signal_cancel();
 };
 
 #endif
