@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,20 +21,30 @@
 
 #ifndef DOWNLOAD_H
 #define DOWNLOAD_H
+#include <map>
 #include <curl/curl.h>
+#include "include/singleton.h"
 
-class Downloader
+class Downloader : public Singleton<Downloader>
 {
+  /* If you need this, implement it (correctly) */
+  Downloader(const Downloader&);
+  const Downloader& operator=(const Downloader&);
+  /**********************************************/
+
   CURL* curl;
-public:
+
+protected:
+  friend class Singleton<Downloader>;
   Downloader();
   ~Downloader();
 
+public:
   // Return true if the download was successful
+  std::string GetLatestVersion();
   bool Get(const char* url, const char* save_as);
+  std::map<std::string, int> GetServerList(std::string list_name);
 };
 
-extern Downloader downloader;
-
 #endif
 
