@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,49 +22,43 @@
 #ifndef BONUS_BOX_H
 #define BONUS_BOX_H
 //-----------------------------------------------------------------------------
-#include <SDL.h>
-#include "../include/base.h"
-#include "../object/physical_obj.h"
-#include "../team/team.h"
-#include "../weapon/weapons_list.h"
+#include <vector>
+#include "include/base.h"
+#include "weapon/weapon.h"
+#include "objbox.h"
+
+// Forward declarations
+class Character;
+class Action;
 //-----------------------------------------------------------------------------
 
-class BonusBox : public PhysicalObj
+struct WeaponProba
+{
+  Weapon* weapon;
+  int nb_ammos;
+  double probability;
+};
+
+class BonusBox : public ObjBox
 {
   private:
-    static bool enable;
-    uint nbr_ammo;
-    static int start_life_points;
+    uint weapon_num;
+    bool ExplodesInsteadOfBonus(Character * c);
 
-    bool parachute; 
-    Sprite *anim;
-
-    Weapon::Weapon_type contents;
-    static uint weapon_count;
-    static std::map<int,std::pair<Weapon*,int> > weapon_map;
-    static std::map<int,std::pair<Weapon*,int> > weapon_map_no_infinite;
+    static double total_probability;
+    static std::vector<struct WeaponProba> weapon_list;
 
   private:
     void ApplyBonus (Team &team, Character &character);
     void PickRandomWeapon();
   public:
     BonusBox();
-    ~BonusBox();
+    static void LoadXml(xmlNode*  object);
 
-    static void Enable (bool _enable);
-    static bool NewBonusBox();
-    void DropBonusBox();
-    static void RemoveInfiniteWeapons();
-    static void LoadXml(xmlpp::Element * object);
-
-    void Draw();
-    void Refresh();
-
-  protected:
-    // Signal Fall ending
-    virtual void SignalCollision();
-    virtual void SignalDrowning();
-    void SignalGhostState(bool was_already_dead);
+    void ApplyBonus(Character *);
+    void Randomize();
+    void GetValueFromAction(Action *);
+    void StoreValue(Action *);
 };
 
 //-----------------------------------------------------------------------------
