@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,10 +22,12 @@
 //-----------------------------------------------------------------------------
 #include <cstring>
 #include <iostream>
-#include "object_cfg.h"
-#include "../game/config.h"
-#include "../include/base.h"
-#include "../tool/xml_document.h"
+#include "object/object_cfg.h"
+#include "game/config.h"
+#include "game/game_mode.h"
+#include "include/base.h"
+#include "tool/debug.h"
+#include "tool/xml_document.h"
 //-----------------------------------------------------------------------------
 
 ObjectConfig::ObjectConfig()
@@ -38,24 +40,31 @@ ObjectConfig::ObjectConfig()
   m_mass = 1.0;
 }
 
-ObjectConfig::~ObjectConfig()
-{
-}
-
 void ObjectConfig::LoadXml(const std::string& obj_name, const std::string &config_file)
 {
-  std::string file;
-  if(config_file=="")
-    file = Config::GetInstance()->GetDataDir() + PATH_SEPARATOR + "game_mode" + PATH_SEPARATOR + "objects.xml";
-  else
-    file = config_file;
-
-  // Load Xml configuration
+  xmlNode* elem = NULL;
   XmlReader doc;
-  assert(doc.Load(file));
-  xmlpp::Element* elem = XmlReader::GetMarker(doc.GetRoot(), obj_name);
 
-  assert(elem != NULL);
+  if (config_file == "") {
+
+    MSG_DEBUG("game_mode", "Load %s configuration from %s\n",
+              obj_name.c_str(),
+              GameMode::GetInstance()->GetName().c_str());
+
+    const XmlReader* ddoc = GameMode::GetInstance()->GetXmlObjects();
+    elem = XmlReader::GetMarker(ddoc->GetRoot(), obj_name);
+
+  } else {
+
+    MSG_DEBUG("game_mode", "** Load %s configuration from file %s\n",
+              obj_name.c_str(), config_file.c_str());
+
+    // Load Xml configuration
+    ASSERT(doc.Load(config_file));
+    elem = XmlReader::GetMarker(doc.GetRoot(), obj_name);
+  }
+
+  ASSERT(elem != NULL);
   XmlReader::ReadDouble(elem, "mass", m_mass);
   XmlReader::ReadDouble(elem, "wind_factor", m_wind_factor);
   XmlReader::ReadDouble(elem, "air_resist_factor", m_air_resist_factor);
