@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,15 +21,15 @@
 
 #ifndef BODY_MEMBER_H
 #define BODY_MEMBER_H
-#include "particle.h"
+#include "particles/particle.h"
 
 class BodyMemberParticle : public Particle
 {
   double angle_rad;
  public:
-  BodyMemberParticle(Sprite* spr, const Point2i& position);
+  BodyMemberParticle(const Sprite* spr, const Point2i& position);
  private:
   void Refresh();
 };
 
-#endif
+#endif /* BODY_MEMBER_H */
