@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 #ifndef EXPLOSION_SMOKE_H
 #define EXPLOSION_SMOKE_H
-#include "particle.h"
+#include "particles/particle.h"
 
 class ExplosionSmoke : public Particle
 {
@@ -34,4 +34,4 @@ class ExplosionSmoke : public Particle
   virtual void Draw();
 };
 
-#endif
+#endif /* EXPLOSION_SMOKE_H */
