@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,11 +21,10 @@
 
 #ifndef FIRE_H
 #define FIRE_H
-#include "particle.h"
+#include "particles/particle.h"
 
 class FireParticle : public Particle
 {
-  int direction;
   int creation_time;
   bool on_ground;
   int oscil_delta;
@@ -39,4 +38,4 @@ class FireParticle : public Particle
     void SignalOutOfMap();
 };
 
-#endif
+#endif /* FIRE_H */
