@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 #ifndef MAGIC_STAR_H
 #define MAGIC_STAR_H
-#include "particle.h"
+#include "particles/particle.h"
 
 class MagicStarParticle: public Particle
 {
@@ -30,4 +30,4 @@ class MagicStarParticle: public Particle
   void Refresh();
 };
 
-#endif
+#endif /* MAGIC_STAR_H */
