@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,42 +19,70 @@
  * Team handling
  *****************************************************************************/
 
-#include "teams_list.h"
+#include "team/team.h"
+#include "team/team_config.h"
+#include "team/teams_list.h"
 //-----------------------------------------------------------------------------
-#include "../character/body_list.h"
-#include "../include/action_handler.h"
-#include "../game/config.h"
-#include "../tool/file_tools.h"
-#include "../tool/i18n.h"
-#include "team_energy.h"
+#include "character/character.h"
+#include "character/body_list.h"
+#include "include/action.h"
+#include "game/config.h"
+#include "network/network.h"
+#include "tool/file_tools.h"
+#include "tool/i18n.h"
+#include "team/team_energy.h"
 #include <algorithm>
 #include <iostream>
+#include "network/randomsync.h"
 
-#if !defined(WIN32) || defined(__MINGW32__)
-#include <dirent.h>
-#include <sys/stat.h>
-#endif
-//-----------------------------------------------------------------------------
-TeamsList teams_list;
 //-----------------------------------------------------------------------------
 //-----------------------------------------------------------------------------
 
-TeamsList::TeamsList()
-{}
+TeamsList::TeamsList():
+  full_list(),
+  playing_list(),
+  selection(),
+  active_team(playing_list.end())
+{
+  LoadList();
+}
 
 TeamsList::~TeamsList()
 {
+  /* The teamslist was never built... nothing to delete.
+   * FIXME This is needed because we are lead to delete things even if they
+   * were not created completely. IMHO, this reflects the fact that the object
+   * life time is not well known...
+   * Actually, this is not that bad whereas free(NULL) is accepted... but it
+   * remains spurious. */
+  if (!singleton)
+  {
+    fprintf(stderr, "Destructor still called on unexisting TeamsList\n");
+    return;
+  }
+
+  UnloadGamingData();
   Clear();
+  for(full_iterator it = full_list.begin(); it != full_list.end(); ++it)
+    delete (*it);
   full_list.clear();
+  singleton = NULL;
 }
 
 //-----------------------------------------------------------------------------
 
-void TeamsList::NextTeam (bool begin_game)
+void TeamsList::NextTeam ()
 {
-  // End of turn for active team
-  if (begin_game) return;
+  Team* next = GetNextTeam();
+  GetTeamsList().SetActive (next->GetId());
+  Action a(Action::ACTION_GAMELOOP_NEXT_TEAM, next->GetId());
+  Network::GetInstance()->SendAction(&a);
+}
 
+//-----------------------------------------------------------------------------
+
+Team* TeamsList::GetNextTeam()
+{
   // Next team
   std::vector<Team*>::iterator it=active_team;
   do
@@ -62,39 +90,41 @@ void TeamsList::NextTeam (bool begin_game)
     ++it;
     if (it == playing_list.end()) it = playing_list.begin();
   } while ((**it).NbAliveCharacter() == 0);
-  ActionHandler::GetInstance()->NewAction(new Action(Action::ACTION_CHANGE_TEAM, (**it).GetId()));
+  return (*it);
 }
 
+
 //-----------------------------------------------------------------------------
 
 Team& TeamsList::ActiveTeam()
 {
-  assert (active_team != playing_list.end());
+  ASSERT (active_team != playing_list.end());
   return **active_team;
 }
 
 //-----------------------------------------------------------------------------
 
-void TeamsList::LoadOneTeam(const std::string &dir, const std::string &team)
+void TeamsList::LoadOneTeam(const std::string &dir, const std::string &team_name)
 {
   // Skip '.', '..' and hidden files
-  if (team[0] == '.') return;
+  if (team_name[0] == '.') return;
 
-#if !defined(WIN32) || defined(__MINGW32__)
   // Is it a directory ?
-  struct stat stat_file;
-  std::string filename = dir+team;
-  if (stat(filename.c_str(), &stat_file) != 0) return;
-  if (!S_ISDIR(stat_file.st_mode)) return;
-#endif
+  if (!IsFolderExist(dir+team_name)) return;
 
   // Add the team
-  Team * tmp = Team::CreateTeam (dir, team);
-  if (tmp != NULL) {
-    full_list.push_back(*tmp);
-    std::cout << ((1<full_list.size())?", ":" ") << team;
+  try {
+    full_list.push_back(new Team(dir, team_name));
+    std::cout << ((1<full_list.size())?", ":" ") << team_name;
     std::cout.flush();
   }
+
+  catch (char const *error) {
+    std::cerr << std::endl
+              << Format(_("Error loading team :")) << team_name <<":"<< error
+              << std::endl;
+    return;
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -105,47 +135,33 @@ void TeamsList::LoadList()
 
   std::cout << "o " << _("Load teams:");
 
+  const Config * config = Config::GetInstance();
+
   // Load Wormux teams
-  std::string dirname = Config::GetInstance()->GetDataDir() + PATH_SEPARATOR + "team" + PATH_SEPARATOR;
-#if !defined(WIN32) || defined(__MINGW32__)
-  struct dirent *file;
-  DIR *dir = opendir(dirname.c_str());
-  if (dir != NULL) {
-    while ((file = readdir(dir)) != NULL)  LoadOneTeam (dirname, file->d_name);
-    closedir (dir);
+  std::string dirname = config->GetDataDir() + "team" PATH_SEPARATOR;
+  FolderSearch *f = OpenFolder(dirname);
+  if (f) {
+    const char *name;
+    while ((name = FolderSearchNext(f)) != NULL) LoadOneTeam(dirname, name);
+    CloseFolder(f);
   } else {
     Error (Format(_("Cannot open teams directory (%s)!"), dirname.c_str()));
   }
-#else
-  std::string pattern = dirname + "*.*";
-  WIN32_FIND_DATA file;
-  HANDLE file_search;
-  file_search=FindFirstFile(pattern.c_str(),&file);
-  if(file_search != INVALID_HANDLE_VALUE)
-  {
-    while (FindNextFile(file_search,&file))
-    {
-      if(file.dwFileAttributes == FILE_ATTRIBUTE_DIRECTORY)
-        LoadOneTeam(dirname,file.cFileName);
-    }
-  } else {
-    Error (Format(_("Cannot open teams directory (%s)!"), dirname.c_str()));
-  }
-  FindClose(file_search);
-#endif
 
   // Load personal teams
-#if !defined(WIN32) || defined(__MINGW32__)
-  dirname = Config::GetInstance()->GetPersonalDir() + PATH_SEPARATOR
-    + "team" + PATH_SEPARATOR;
-  dir = opendir(dirname.c_str());
-  if (dir != NULL) {
-    while ((file = readdir(dir)) != NULL) LoadOneTeam (dirname, file->d_name);
-    closedir (dir);
+  dirname = config->GetPersonalDataDir() + "team" PATH_SEPARATOR;
+  f = OpenFolder(dirname);
+  if (f) {
+    const char *name;
+    while ((name = FolderSearchNext(f)) != NULL) LoadOneTeam(dirname, name);
+    CloseFolder(f);
+  } else {
+    std::cerr << std::endl
+      << Format(_("Cannot open personal teams directory (%s)!"), dirname.c_str())
+      << std::endl;
   }
-#endif
 
-  teams_list.full_list.sort(compareTeams);
+  full_list.sort(compareTeams);
 
   // We need at least 2 teams
   if (full_list.size() < 2)
@@ -158,18 +174,28 @@ void TeamsList::LoadList()
   ChangeSelection (nv_selection);
 
   std::cout << std::endl;
+  InitList(Config::GetInstance()->AccessTeamList());
 }
 
 //-----------------------------------------------------------------------------
 
-void TeamsList::LoadGamingData(uint how_many_characters)
+void TeamsList::LoadGamingData()
 {
+  std::sort(playing_list.begin(), playing_list.end(), compareTeams); // needed to fix bug #9820
   active_team = playing_list.begin();
 
   iterator it=playing_list.begin(), end=playing_list.end();
 
   // Load the data of all teams
-  for (; it != end; ++it) (**it).LoadGamingData(how_many_characters);
+  for (; it != end; ++it) (**it).LoadGamingData();
+}
+
+void TeamsList::RandomizeFirstPlayer()
+{
+  active_team = playing_list.begin();
+  int skip = randomSync.GetLong(0, playing_list.size() - 1);
+  for(int i = 0; i < skip; i++)
+    active_team++;
 }
 
 //-----------------------------------------------------------------------------
@@ -177,7 +203,7 @@ void TeamsList::LoadGamingData(uint how_many_characters)
 void TeamsList::UnloadGamingData()
 {
   body_list.FreeMem();
-  iterator it=playing_list.begin(), end=playing_list.end();
+  iterator it=playing_list.begin(), end = playing_list.end();
 
   // Unload the data of all teams
   for (; it != end; ++it) (**it).UnloadGamingData();
@@ -187,14 +213,14 @@ void TeamsList::UnloadGamingData()
 
 Team *TeamsList::FindById (const std::string &id, int &pos)
 {
-  full_iterator it=full_list.begin(), fin=full_list.end();
+  full_iterator it=full_list.begin(), end = full_list.end();
   int i=0;
-  for (; it != fin; ++it, ++i)
+  for (; it != end; ++it, ++i)
   {
-    if (it -> GetId() == id)
+    if ((*it)->GetId() == id)
     {
       pos = i;
-      return &(*it);
+      return (*it);
     }
   }
   pos = -1;
@@ -205,13 +231,14 @@ Team *TeamsList::FindById (const std::string &id, int &pos)
 
 Team *TeamsList::FindByIndex (uint index)
 {
-  full_iterator it=full_list.begin(), fin=full_list.end();
+  full_iterator it=full_list.begin(), end = full_list.end();
   uint i=0;
-  for (; it != fin; ++it, ++i)
+  for (; it != end; ++it, ++i)
   {
-    if (i == index) return &(*it);
+    if (i == index)
+      return (*it);
   }
-  assert (false);
+  ASSERT (false);
   return NULL;
 }
 
@@ -219,13 +246,13 @@ Team *TeamsList::FindByIndex (uint index)
 
 Team *TeamsList::FindPlayingByIndex (uint index)
 {
-  assert(index < playing_list.size());
+  ASSERT(index < playing_list.size());
   return playing_list[index];
 }
 
 //-----------------------------------------------------------------------------
 
-Team* TeamsList::FindPlayingById(const std::string &id, uint &index)
+Team* TeamsList::FindPlayingById(const std::string &id, int &index)
 {
   iterator it = playing_list.begin(), end = playing_list.end();
   index=0;
@@ -234,7 +261,9 @@ Team* TeamsList::FindPlayingById(const std::string &id, uint &index)
     if ((*it) -> GetId() == id)
       return *it;
   }
-  assert(false);
+
+  index = -1;
+  ASSERT(false);
   return NULL;
 }
 
@@ -256,9 +285,9 @@ void TeamsList::InitEnergy()
 {
   // Looking at team with the greatest energy
   // (in case teams does not have same amount of character)
-  iterator it=playing_list.begin(), fin=playing_list.end();
+  iterator it=playing_list.begin(), end = playing_list.end();
   uint max = 0;
-  for (; it != fin; ++it)
+  for (; it != end; ++it)
   {
     if( (**it).ReadEnergy() > max)
       max = (**it).ReadEnergy();
@@ -266,20 +295,18 @@ void TeamsList::InitEnergy()
 
   // Init each team's energy bar
   it=playing_list.begin();
-  uint i = 0;
-  for (; it != fin; ++it)
+  for (; it != end; ++it)
   {
     (**it).InitEnergy (max);
-    ++i;
   }
 
   // Initial ranking
   it=playing_list.begin();
-  for (; it != fin; ++it)
+  for (; it != end; ++it)
   {
     uint rank = 0;
     iterator it2=playing_list.begin();
-    for (; it2 != fin; ++it2)
+    for (; it2 != end; ++it2)
     {
       if((it != it2)
           && (**it2).ReadEnergy() > (**it).ReadEnergy() )
@@ -288,11 +315,11 @@ void TeamsList::InitEnergy()
     (**it).energy.rank_tmp = rank;
   }
   it=playing_list.begin();
-  for (; it != fin; ++it)
+  for (; it != end; ++it)
   {
     uint rank = (**it).energy.rank_tmp;
     iterator it2=playing_list.begin();
-    for (it2 = it; it2 != fin; ++it2)
+    for (it2 = it; it2 != end; ++it2)
     {
       if((it != it2)
           && (**it2).ReadEnergy() == (**it).ReadEnergy() )
@@ -312,12 +339,12 @@ void TeamsList::RefreshEnergy()
   // - change ranking
   // - prepare energy bar for next event
 
-  iterator it=playing_list.begin(), fin=playing_list.end();
+  iterator it=playing_list.begin(), end = playing_list.end();
   energy_t status;
 
   bool waiting = true; // every energy bar are waiting
 
-  for (; it != fin; ++it) {
+  for (; it != end; ++it) {
     if( (**it).energy.status != EnergyStatusWait) {
       waiting = false;
       break;
@@ -329,7 +356,7 @@ void TeamsList::RefreshEnergy()
     status = EnergyStatusOK;
 
     // change an energy bar value ?
-    for (it=playing_list.begin(); it != fin; ++it) {
+    for (it=playing_list.begin(); it != end; ++it) {
       if( (**it).energy.status == EnergyStatusValueChange) {
         status = EnergyStatusValueChange;
         break;
@@ -337,7 +364,7 @@ void TeamsList::RefreshEnergy()
     }
 
     // change a ranking ?
-    for (it=playing_list.begin(); it != fin; ++it) {
+    for (it=playing_list.begin(); it != end; ++it) {
       if( (**it).energy.status == EnergyStatusRankChange
              && ((**it).energy.IsMoving() || status == EnergyStatusOK)) {
         status = EnergyStatusRankChange;
@@ -354,13 +381,13 @@ void TeamsList::RefreshEnergy()
   // Setting event to process in every energy bar
   if(status != EnergyStatusOK || waiting) {
     it=playing_list.begin();
-    for (; it != fin; ++it) {
+    for (; it != end; ++it) {
       (**it).energy.status = status;
     }
   }
 
   // Actualisation des valeurs (pas d'actualisation de l'affichage)
-  for (it=playing_list.begin(); it != fin; ++it) {
+  for (it=playing_list.begin(); it != end; ++it) {
     (**it).UpdateEnergyBar();
     RefreshSort();
   }
@@ -369,16 +396,16 @@ void TeamsList::RefreshEnergy()
 
 void TeamsList::RefreshSort ()
 {
-  iterator it=playing_list.begin(), fin=playing_list.end();
+  iterator it=playing_list.begin(), end = playing_list.end();
   uint rank;
 
   // Find a ranking without taking acount of the equalities
   it=playing_list.begin();
-  for (; it != fin; ++it)
+  for (; it != end; ++it)
   {
     rank = 0;
     iterator it2=playing_list.begin();
-    for (; it2 != fin; ++it2)
+    for (; it2 != end; ++it2)
     {
       if((it != it2)
           && (**it2).ReadEnergy() > (**it).ReadEnergy() )
@@ -389,11 +416,11 @@ void TeamsList::RefreshSort ()
 
   // Fix equalities
   it=playing_list.begin();
-  for (; it != fin; ++it)
+  for (; it != end; ++it)
   {
     rank = (**it).energy.rank_tmp;
     iterator it2=playing_list.begin();
-    for (it2 = it; it2 != fin; ++it2)
+    for (it2 = it; it2 != end; ++it2)
     {
       if((it != it2)
           && (**it2).ReadEnergy() == (**it).ReadEnergy() )
@@ -409,9 +436,9 @@ void TeamsList::ChangeSelection (const std::list<uint>& nv_selection)
 {
   selection = nv_selection;
 
-  selection_iterator it=selection.begin(), fin=selection.end();
+  selection_iterator it=selection.begin(), end = selection.end();
   playing_list.clear();
-  for (; it != fin; ++it) playing_list.push_back (FindByIndex(*it));
+  for (; it != end; ++it) playing_list.push_back (FindByIndex(*it));
   active_team = playing_list.begin();
 }
 
@@ -481,10 +508,19 @@ void TeamsList::DelTeam (const std::string &id)
 {
   int pos;
   Team *equipe = FindById (id, pos);
-  assert(equipe != NULL);
+  ASSERT(equipe != NULL);
 
-  selection.erase(find(selection.begin(),selection.end(),(uint)pos));
-  playing_list.erase(find(playing_list.begin(),playing_list.end(),equipe));
+  selection_iterator it = find(selection.begin(), selection.end(), (uint)pos);
+
+  if (it != selection.end()) {
+    selection.erase(it);
+  }
+
+  iterator playing_it = find(playing_list.begin(), playing_list.end(), equipe);
+
+  if (playing_it != playing_list.end()) {
+    playing_list.erase(playing_it);
+  }
 
   active_team = playing_list.begin();
 }
@@ -493,8 +529,7 @@ void TeamsList::DelTeam (const std::string &id)
 
 void TeamsList::SetActive(const std::string &id)
 {
-  iterator
-      it = playing_list.begin(),
+  iterator it = playing_list.begin(),
   end = playing_list.end();
   for (; it != end; ++it)
   {
@@ -502,6 +537,7 @@ void TeamsList::SetActive(const std::string &id)
     if (team.GetId() == id)
     {
       active_team = it;
+      ActiveTeam().PrepareTurn();
       return;
     }
   }
@@ -512,7 +548,7 @@ void TeamsList::SetActive(const std::string &id)
 
 Team& ActiveTeam()
 {
-  return teams_list.ActiveTeam();
+  return GetTeamsList().ActiveTeam();
 }
 
 //-----------------------------------------------------------------------------
@@ -524,9 +560,9 @@ Character& ActiveCharacter()
 
 //-----------------------------------------------------------------------------
 
-bool compareTeams(const Team& a, const Team& b)
+bool compareTeams(const Team *a, const Team *b)
 {
-  return a.GetName() < b.GetName();
+  return a->GetName() < b->GetName();
 }
 
 //-----------------------------------------------------------------------------
