@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,35 +22,46 @@
 #ifndef TEAMS_LIST_H
 #define TEAMS_LIST_H
 //-----------------------------------------------------------------------------
-#include "team.h"
-#include "team_config.h"
 #include <list>
+#include <vector>
+#include "include/singleton.h"
 //-----------------------------------------------------------------------------
 
-class TeamsList
+// Forward declarations
+class Team;
+class ConfigTeam;
+class Character;
+
+class TeamsList : public Singleton<TeamsList>
 {
 public:
-  typedef std::list<Team>::iterator full_iterator;
-  typedef std::vector<Team*>::iterator iterator;
-  std::list<Team> full_list;
+  typedef std::list<Team *>::iterator full_iterator;
+  typedef std::vector<Team *>::iterator iterator;
+  std::list<Team *> full_list;
   std::vector<Team*> playing_list;
 
 private:
   typedef std::list<uint>::iterator selection_iterator;
   std::list<uint> selection;
   std::vector<Team*>::iterator active_team;
-  void LoadOneTeam (const std::string &dir, const std::string &file);
 
-public:
+  void LoadOneTeam (const std::string &dir, const std::string &file);
+  void LoadList();
+
+protected:
+  friend class Singleton<TeamsList>;
   TeamsList();
   ~TeamsList();
-  void LoadList ();
-  void NextTeam (bool begin_game);
+
+public:
+  friend TeamsList &GetTeamsList(void);
+  void NextTeam();
+  Team* GetNextTeam();
   Team& ActiveTeam();
-  void LoadGamingData(uint how_many_characters);
+  void LoadGamingData();
   void UnloadGamingData();
   void Clear();
-
+  void RandomizeFirstPlayer();
 
   // Add a new team to playing, and change active team
   void AddTeam (const ConfigTeam& the_team_cfg, bool generate_error=true);
@@ -63,16 +74,16 @@ public:
   void RefreshSort (); //Refresh energy bar position
   void ChangeSelection (const std::list<uint>& liste);
   bool IsSelected (uint index);
+  static bool IsLoaded() { return singleton != NULL; }
 
   // Find a team by its id or index (in full_list)
   Team* FindById (const std::string &id, int &pos);
   Team* FindByIndex (uint index);
   // Find a team by its id or index (in playing full_list)
-  Team* FindPlayingById(const std::string &id, uint &index);
+  Team* FindPlayingById(const std::string &id, int &index);
   Team* FindPlayingByIndex(uint index);
 };
 
-extern TeamsList teams_list;
 //-----------------------------------------------------------------------------
 
 // current active team
@@ -83,7 +94,9 @@ Character& ActiveCharacter();
 
 //-----------------------------------------------------------------------------
 
-bool compareTeams(const Team& a, const Team& b);
+bool compareTeams(const Team *a, const Team *b);
+
+inline TeamsList &GetTeamsList(void) { return TeamsList::GetRef(); };
 
 //-----------------------------------------------------------------------------
 #endif
