@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,27 +20,36 @@
 #ifndef DEBUG_H
 #define DEBUG_H
 
-/** Usage example : 
+#include <string>
+
+/** Usage example :
  *
  * MSG_DEBUG( "game.pause", "Salut %s", "Truc" )
- * 
+ *
  * MSG_DEBUG use standart printf style for the message.
- * 
+ *
  * A debug will be printed only if there is a mode game or game.pause. A mode can be added by running wormux with:
  * ./wormux -d game        # print all messages in game section
  * ./wormux -d ""          # print all debug messages
  *
  */
-#ifdef DEBUG
-#  define MSG_DEBUG(LEVEL, MESSAGE, ARGS...) \
-	PrintDebug( __FILE__, __PRETTY_FUNCTION__, __LINE__, LEVEL, MESSAGE, ## ARGS);
+#ifdef WMX_LOG
+#  define MSG_DEBUG(LEVEL, MESSAGE, ...) \
+   PrintDebug( __FILE__, __FUNCTION__, __LINE__, LEVEL, MESSAGE, ## __VA_ARGS__)
 #else
-#  define MSG_DEBUG(LEVEL, MESSAGE, ARGS...)
+#  define MSG_DEBUG(LEVEL, MESSAGE, ...) do {} while (0)
 #endif
 
+extern bool debug_all;
+
 void PrintDebug (const char *filename, const char *function, unsigned long line,
                  const char *level, const char *message, ...);
-void AddDebugMode( std::string mode );
-void InitDebugModes( int argc, char **argv );
+void AddDebugMode(const std::string& mode);
+
+#ifdef WMX_LOG
+bool IsLOGGING(const char* mode);
+#else
+#  define IsLOGGING(a) false
+#endif
 
 #endif
