@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,10 +21,13 @@
 
 #ifndef FILE_TOOLS_H
 #define FILE_TOOLS_H
-#include "../include/base.h"
+#include "include/base.h"
 
 // Check if a file exists
-bool IsFileExist(const std::string &name);
+bool DoesFileExist(const std::string &name);
+
+// Check if the folder exists
+bool IsFolderExist(const std::string &name);
 
 // Find the extension part of a filename
 std::string FileExtension(const std::string &name);
@@ -35,4 +38,10 @@ std::string GetHome ();
 // Replace ~ by its true name
 std::string TranslateDirectory(const std::string &directory);
 
+typedef struct _FolderSearch FolderSearch;
+
+FolderSearch *OpenFolder(const std::string& dirname);
+const char* FolderSearchNext(FolderSearch *f);
+void CloseFolder(FolderSearch *f);
+
 #endif
