@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,49 +19,71 @@
  * AirHammer - Use it to dig
  *****************************************************************************/
 
-#include "../weapon/airhammer.h"
+#include "weapon/airhammer.h"
+#include "weapon/explosion.h"
+#include "weapon/weapon_cfg.h"
+
 //-----------------------------------------------------------------------------
 #include <sstream>
-#include "../game/game.h"
-#include "../game/game_loop.h"
-#include "../game/time.h"
-#include "../include/action_handler.h"
-#include "../map/map.h"
-#include "../object/objects_list.h"
-#include "../team/teams_list.h"
-#include "../team/macro.h"
-#include "../tool/i18n.h"
-#include "../interface/game_msg.h"
-#include "../weapon/explosion.h"
+#include "character/character.h"
+#include "game/game.h"
+#include "game/time.h"
+#include "include/action_handler.h"
+#include "interface/game_msg.h"
+#include "map/map.h"
+#include "object/objects_list.h"
+#include "sound/jukebox.h"
+#include "team/teams_list.h"
+#include "team/macro.h"
+#include "team/team.h"
+#include "tool/i18n.h"
+#include "tool/resource_manager.h"
+#include "tool/xml_document.h"
 
 //-----------------------------------------------------------------------------
 
 const uint MIN_TIME_BETWEEN_JOLT = 100; // in milliseconds
 
 //-----------------------------------------------------------------------------
+
+class AirhammerConfig : public WeaponConfig
+{
+  public:
+    uint range;
+    uint damage;
+    AirhammerConfig();
+    void LoadXml(xmlNode* elem);
+};
+
 //-----------------------------------------------------------------------------
 
 Airhammer::Airhammer() : Weapon(WEAPON_AIR_HAMMER,"airhammer",new AirhammerConfig())
 {
-  m_name = _("Airhammer");
-  override_keys = true ;
+  UpdateTranslationStrings();
+
+  m_category = TOOL;
 
   impact = resource_manager.LoadImage( weapons_res_profile, "airhammer_impact");
-  m_last_jolt = 0;
+  m_time_between_each_shot = MIN_TIME_BETWEEN_JOLT;
 }
 
 //-----------------------------------------------------------------------------
 
-void Airhammer::p_Deselect()
+void Airhammer::UpdateTranslationStrings()
 {
-  m_is_active = false;
+  m_name = _("Airhammer");
+  m_help = _("Howto use it : keep space key pressed\nan ammo per turn");
 }
 
 //-----------------------------------------------------------------------------
 
 bool Airhammer::p_Shoot()
 {
-  jukebox.Play("share","weapon/airhammer");
+  //if the sound isn't already playing, play it again.
+  select_sound.Stop();
+  if (!drill_sound.IsPlaying()) {
+    drill_sound.Play("share","weapon/airhammer", -1);
+  }
 
   // initiate movement ;-)
   ActiveCharacter().SetRebounding(false);
@@ -71,7 +93,7 @@ bool Airhammer::p_Shoot()
 
   Point2i pos = Point2i(ActiveCharacter().GetX() + ActiveCharacter().GetWidth()/2 - impact.GetWidth()/2,
                         ActiveCharacter().GetTestRect().GetPositionY() +
-                        ActiveCharacter().GetHeight()  -15);
+                        ActiveCharacter().GetHeight()  -16);
 
   ParticleEngine::AddNow(pos + Point2i(impact.GetWidth()/4,9), 1, particle_AIR_HAMMER,
                          true, -3.0 * M_PI_4, 5.0 + Time::GetInstance()->Read() % 5);
@@ -100,10 +122,10 @@ bool Airhammer::p_Shoot()
     if (&(*character) != &ActiveCharacter())
     {
       // Did we touch somebody ?
-      if( character->ObjTouche(Point2i(x, y)) )
+      if( character->Contain(Point2i(x, y)) )
       {
         // Apply damage (*ver).SetEnergyDelta (-cfg().damage);
-        character->SetEnergyDelta(-cfg().damage);
+        character->SetEnergyDelta(-(int)cfg().damage);
         end = true;
       }
     }
@@ -114,51 +136,47 @@ bool Airhammer::p_Shoot()
 
 //-----------------------------------------------------------------------------
 
-void Airhammer::RepeatShoot()
+void Airhammer::ActionStopUse()
 {
-  uint time = Time::GetInstance()->Read() - m_last_jolt;
-  uint tmp = Time::GetInstance()->Read();
-
-  if (time >= MIN_TIME_BETWEEN_JOLT)
-  {
-    m_is_active = false;
-    NewActionShoot();
-    m_last_jolt = tmp;
-  }
+  ActiveTeam().AccessNbUnits() = 0; // ammo units are lost
+  Game::GetInstance()->SetState(Game::HAS_PLAYED);
+  p_Deselect();
+}
 
+void Airhammer::p_Deselect()
+{
+  drill_sound.Stop();
+  select_sound.Stop();
 }
 
 //-----------------------------------------------------------------------------
 
-void Airhammer::Refresh()
+void Airhammer::HandleKeyRefreshed_Shoot(bool)
 {
-}
-
-//-----------------------------------------------------------------------------
-
-void Airhammer::HandleKeyEvent(Action::Action_t action, Keyboard::Key_Event_t event_type)
-{
-  switch (action) {
-
-    case Action::ACTION_SHOOT:
-
-      if (event_type == Keyboard::KEY_RELEASED || ActiveCharacter().GotInjured()) {
-        // stop when key is released or character got injured
-        ActiveTeam().AccessNbUnits() = 0;
-        m_is_active = false;
-        GameLoop::GetInstance()->SetState(GameLoop::HAS_PLAYED);
-      }
-
-      if (event_type == Keyboard::KEY_REFRESH)
-        RepeatShoot();
-
-      break ;
-
-    default:
-      break ;
+  if (EnoughAmmoUnit()) {
+    Weapon::RepeatShoot();
   }
-
 }
+
+bool Airhammer::IsInUse() const
+{
+  return m_last_fire_time + m_time_between_each_shot > Time::GetInstance()->Read();
+}
+
+void Airhammer::p_Select()
+{
+  select_sound.Play("share","weapon/airhammer_select",-1);
+}
+
+std::string Airhammer::GetWeaponWinString(const char *TeamName, uint items_count ) const
+{
+  return Format(ngettext(
+            "%s team has won %u airhammer! Don't make too much noise with it! Thanks, your neighbours.",
+            "%s team has won %u airhammers! Don't make too much noise with them! Thanks, your neighbours.",
+            items_count), TeamName, items_count);
+}
+
+
 //-----------------------------------------------------------------------------
 
 AirhammerConfig& Airhammer::cfg() {
@@ -174,7 +192,7 @@ AirhammerConfig::AirhammerConfig(){
 
 //-----------------------------------------------------------------------------
 
-void AirhammerConfig::LoadXml(xmlpp::Element *elem){
+void AirhammerConfig::LoadXml(xmlNode* elem){
   WeaponConfig::LoadXml(elem);
   XmlReader::ReadUint(elem, "range", range);
   XmlReader::ReadUint(elem, "damage", damage);
