@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,35 +22,38 @@
 #ifndef ALL_WEAPONS_H
 #define ALL_WEAPONS_H
 
-#include "airhammer.h"
-#include "air_attack.h"
-#include "anvil.h"
-#include "auto_bazooka.h"
-#include "baseball.h"
-#include "bazooka.h"
-#include "blowtorch.h"
-#include "bounce_ball.h"
-#include "cluster_bomb.h"
-#include "construct.h"
-#include "dynamite.h"
-#include "gnu.h"
-#include "grenade.h"
-#include "gun.h"
-#include "disco_grenade.h"
-#include "jetpack.h"
-#include "lowgrav.h"
-#include "mine.h"
-#include "ninja_rope.h"
-#include "parachute.h"
-#include "polecat.h"
-#include "riot_bomb.h"
-#include "shotgun.h"
-#include "skip_turn.h"
-#include "snipe_rifle.h"
-#include "submachine_gun.h"
-#include "suicide.h"
-#include "supertux.h"
-#include "teleportation.h"
-#include "syringe.h"
+#include "weapon/airhammer.h"
+#include "weapon/air_attack.h"
+#include "weapon/anvil.h"
+#include "weapon/auto_bazooka.h"
+#include "weapon/baseball.h"
+#include "weapon/bazooka.h"
+#include "weapon/blowtorch.h"
+#include "weapon/bounce_ball.h"
+#include "weapon/cluster_bomb.h"
+#include "weapon/construct.h"
+#include "weapon/disco_grenade.h"
+#include "weapon/dynamite.h"
+#include "weapon/flamethrower.h"
+#include "weapon/gnu.h"
+#include "weapon/grapple.h"
+#include "weapon/grenade.h"
+#include "weapon/gun.h"
+#include "weapon/jetpack.h"
+#include "weapon/lowgrav.h"
+#include "weapon/mine.h"
+#include "weapon/parachute.h"
+#include "weapon/polecat.h"
+#include "weapon/riot_bomb.h"
+#include "weapon/shotgun.h"
+#include "weapon/skip_turn.h"
+#include "weapon/snipe_rifle.h"
+#include "weapon/submachine_gun.h"
+#include "weapon/suicide.h"
+#include "weapon/supertux.h"
+#include "weapon/syringe.h"
+#include "weapon/teleportation.h"
+#include "weapon/cluzooka.h"
+#include "weapon/footbomb.h"
 
 #endif
