@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,59 +21,32 @@
 
 #ifndef AUTO_BAZOOKA_H
 #define AUTO_BAZOOKA_H
-#include "launcher.h"
-#include "../graphic/surface.h"
-#include "../gui/progress_bar.h"
-#include "../include/base.h"
-#include "../object/physical_obj.h"
 
-class AutomaticBazooka;
+#include "weapon/weapon_launcher.h"
+#include "include/base.h"
+
 class AutomaticBazookaConfig;
-
-class RPG : public WeaponProjectile
-{
-  ParticleEngine smoke_engine;
-  protected:
-    double angle_local;
-    Point2i m_target;
-    bool m_targeted;
-    double m_force;
-    uint m_lastrefresh;
-  public:
-    RPG(AutomaticBazookaConfig& cfg,
-                        WeaponLauncher * p_launcher);
-    void Refresh();
-    void Shoot(double strength);
-    void SetTarget (int x,int y);
-
-  protected:
-    void SignalOutOfMap();
-    void SignalDrowning();
-};
+struct target_t;
 
 class AutomaticBazooka : public WeaponLauncher
 {
-  private:
-    struct target_t
-    {
-      Point2i pos;
-      bool selected;
-      Surface image;
-    } m_target;
+  target_t       *m_target;
   public:
     AutomaticBazooka();
+    ~AutomaticBazooka();
     void Draw ();
     bool IsReady() const;
     virtual void ChooseTarget(Point2i mouse_pos);
     AutomaticBazookaConfig &cfg();
+    void UpdateTranslationStrings();
+    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
   protected:
     void Refresh();
-    void p_Select(); 
+    void p_Select();
     void p_Deselect();
 
-    void DrawTarget();
+    void DrawTarget() const;
 
-  protected:
     WeaponProjectile * GetProjectileInstance();
 };
 
