@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,15 +19,19 @@
  * Weapon's crosshair
  *****************************************************************************/
 
-#include "crosshair.h"
-#include "weapon.h"
-#include "../game/game_loop.h"
-#include "../graphic/surface.h"
-#include "../include/app.h"
-#include "../map/camera.h"
-#include "../map/map.h"
-#include "../team/teams_list.h"
-#include "../tool/math_tools.h"
+#include "character/character.h"
+#include "weapon/crosshair.h"
+#include "weapon/weapon.h"
+#include "game/game.h"
+#include "graphic/surface.h"
+#include "graphic/video.h"
+#include "include/app.h"
+#include "map/camera.h"
+#include "map/map.h"
+#include "team/teams_list.h"
+#include "team/team.h"
+#include "tool/math_tools.h"
+#include "tool/resource_manager.h"
 
 // Distance between crosshair and character
 #define RAY 40 // pixels
@@ -35,12 +39,13 @@
 CrossHair::CrossHair()
 {
   enable = false;
+  display = false;
   Profile *res = resource_manager.LoadXMLProfile( "graphism.xml", false);
   image = resource_manager.LoadImage(res, "gfx/pointeur1");
   resource_manager.UnLoadXMLProfile(res);
 }
 
-void CrossHair::Reset()
+void CrossHair::Reset() const
 {
   ActiveCharacter().SetFiringAngle(0.0);
 }
@@ -51,15 +56,15 @@ void CrossHair::Refresh(double angle)
   crosshair_position = Point2i(RAY, RAY) * Point2d(cos(angle), sin(angle)) - image.GetSize() / 2;
 }
 
-void CrossHair::Draw()
+void CrossHair::Draw() const
 {
-  if( !enable )
+  if(!display || !enable)
     return;
-  if( ActiveCharacter().IsDead() )
+  if(ActiveCharacter().IsDead())
     return;
-  if( GameLoop::GetInstance()->ReadState() != GameLoop::PLAYING )
+  if(Game::GetInstance()->ReadState() != Game::PLAYING)
     return;
-  Point2i tmp = ActiveCharacter().GetHandPosition() + crosshair_position;
-  AppWormux::GetInstance()->video.window.Blit(image, tmp - camera.GetPosition());
+  Point2i tmp = ActiveTeam().GetWeapon().GetGunHolePosition() + crosshair_position;
+  AppWormux::GetInstance()->video->window.Blit(image, tmp - Camera::GetInstance()->GetPosition());
   world.ToRedrawOnMap(Rectanglei(tmp, image.GetSize()));
 }
