@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,14 +22,15 @@
 #ifndef CROSSHAIR_H
 #define CROSSHAIR_H
 
-#include "../graphic/surface.h"
-#include "../include/base.h"
-#include "../tool/point.h"
+#include "graphic/surface.h"
+#include "include/base.h"
+#include "tool/point.h"
 
 class CrossHair
 {
 public:
   bool enable;
+  bool display;
 
 private:
   Surface image;
@@ -38,13 +39,14 @@ private:
 public:
   CrossHair();
 
-  void Reset();
+  void Reset() const;
 
   // Refresh crosshair angle
   void Refresh(double angle);
 
   // Draw crosshair
-  void Draw();
+  void Draw() const;
+
 };
 
 #endif /* CROSSHAIR_H */
