@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,25 +21,39 @@
  * Like a dynamite after all :)
  *****************************************************************************/
 
-#include "dynamite.h"
-#include "explosion.h"
-#include "../game/config.h"
-#include "../include/app.h"
-#include "../object/objects_list.h"
-#include "../team/teams_list.h"
-#include "../tool/i18n.h"
-#include "../tool/resource_manager.h"
-#include "../tool/debug.h"
+#include "weapon/dynamite.h"
+#include "weapon/explosion.h"
+#include "weapon/weapon_cfg.h"
 
-#ifdef __MINGW32__
-#undef LoadImage
-#endif
+#include "character/character.h"
+#include "game/config.h"
+#include "graphic/sprite.h"
+#include "team/teams_list.h"
+#include "tool/i18n.h"
+#include "tool/resource_manager.h"
+#include "tool/debug.h"
+
+class DynamiteStick : public WeaponProjectile
+{
+  SoundSample timeout_sound;
+
+  public:
+    DynamiteStick(ExplosiveWeaponConfig& cfg,
+                  WeaponLauncher * p_launcher);
+
+    void Shoot(double strength);
+    void Refresh();
+
+  protected:
+    void SignalExplosion();
+    void SignalOutOfMap();
+    void SignalDrowning();
+};
 
 DynamiteStick::DynamiteStick(ExplosiveWeaponConfig& cfg,
                              WeaponLauncher * p_launcher) :
   WeaponProjectile("dynamite_bullet", cfg, p_launcher)
 {
-  channel = -1;
   explode_with_collision = false;
 
   image->animation.SetLoopMode(false);
@@ -55,43 +69,55 @@ void DynamiteStick::Shoot(double strength)
   image->Scale(ActiveCharacter().GetDirection(), 1);
   image->SetCurrentFrame(0);
   image->Start();
+
+  // Sound must be launched before WeaponProjectile::Shoot
+  // in case that the projectile leave the battlefield
+  // during WeaponProjectile::Shoot (#bug 10241)
+  timeout_sound.Play("share","weapon/dynamite_fuze", -1);
+
   WeaponProjectile::Shoot(strength);
 }
 
 void DynamiteStick::Refresh()
 {
   image->Update();
-  if (image->IsFinished()) Explosion();
-}
-
-void DynamiteStick::ShootSound()
-{
-  channel = jukebox.Play("share","weapon/dynamite_fuze", -1);
+  if (image->IsFinished())
+    m_energy = 0;
+  WeaponProjectile::Refresh();
 }
 
 void DynamiteStick::SignalExplosion()
 {
-  jukebox.Stop(channel);
+  timeout_sound.Stop();
 }
 
 void DynamiteStick::SignalOutOfMap()
 {
-  jukebox.Stop(channel);
+  timeout_sound.Stop();
 }
 
 void DynamiteStick::SignalDrowning()
 {
-  jukebox.Stop(channel);
+  timeout_sound.Stop();
 }
 //-----------------------------------------------------------------------------
 
 Dynamite::Dynamite() :
     WeaponLauncher(WEAPON_DYNAMITE, "dynamite", new ExplosiveWeaponConfig(), VISIBLE_ONLY_WHEN_INACTIVE)
 {
-  m_name = _("Dynamite");
+  UpdateTranslationStrings();
+
+  m_category = THROW;
   ReloadLauncher();
 }
 
+void Dynamite::UpdateTranslationStrings()
+{
+  m_name = _("Dynamite");
+  /*TODO: FILL IT */
+  /* m_help = _(""); */
+}
+
 WeaponProjectile * Dynamite::GetProjectileInstance()
 {
   return dynamic_cast<WeaponProjectile *>
@@ -102,12 +128,22 @@ WeaponProjectile * Dynamite::GetProjectileInstance()
 bool Dynamite::p_Shoot ()
 {
   projectile->Shoot(0);
-
   // add the character speed
   if(ActiveCharacter().GetDirection() == 1)
     projectile->SetSpeed(3.0, -M_PI_4);
   else
     projectile->SetSpeed(3.0, -3.0 * M_PI_4);
 
+  projectile = NULL;
+  ReloadLauncher();
   return true;
 }
+
+std::string Dynamite::GetWeaponWinString(const char *TeamName, uint items_count) const
+{
+  return Format(ngettext(
+            "%s team has won %u dynamite!",
+            "%s team has won %u dynamites!",
+            items_count), TeamName, items_count);
+}
+
