@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,35 +22,16 @@
 #ifndef GNU_H
 #define GNU_H
 
-#include <SDL.h>
-#include "grenade.h"
-#include "weapon.h"
-#include "../graphic/sprite.h"
-#include "../gui/progress_bar.h"
-#include "../include/base.h"
-#include "../object/physical_obj.h"
-
-class GnuLauncher;
+#include "weapon/weapon_launcher.h"
 
 // The GNU
-class Gnu : public WeaponProjectile
-{
- private:
-  int m_sens;
-  int save_x, save_y;
- protected:
-  void SignalOutOfMap();
-public:
-  Gnu(ExplosiveWeaponConfig& cfg,
-      WeaponLauncher * p_launcher);
-  void Shoot(double strength);
-  void Refresh();
-};
-
 class GnuLauncher : public WeaponLauncher
 {
 public:
   GnuLauncher();
+
+  void UpdateTranslationStrings();
+  std::string GetWeaponWinString(const char *TeamName, uint items_count) const;
 protected:
   WeaponProjectile * GetProjectileInstance();
 };
