@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,21 +20,32 @@
  * if we hit a character.
  *****************************************************************************/
 
-#include "../weapon/gun.h"
+#include "weapon/gun.h"
+#include "weapon/explosion.h"
+#include "weapon/weapon_cfg.h"
+
 #include <sstream>
-#include "../map/map.h"
-#include "../game/time.h"
-#include "../object/objects_list.h"
-#include "../team/teams_list.h"
-#include "../tool/i18n.h"
-#include "../interface/game_msg.h"
-#include "../interface/game_msg.h"
-#include "../weapon/gun.h"
-#include "../tool/math_tools.h"
-#include "../weapon/explosion.h"
+#include "map/map.h"
+#include "graphic/sprite.h"
+#include "interface/game_msg.h"
+#include "object/objects_list.h"
+#include "sound/jukebox.h"
+#include "team/teams_list.h"
+#include "tool/i18n.h"
+#include "tool/math_tools.h"
+#include "tool/resource_manager.h"
 
 const uint GUN_BULLET_SPEED = 20;
 
+class GunBullet : public WeaponBullet
+{
+  public:
+    GunBullet(ExplosiveWeaponConfig& cfg,
+              WeaponLauncher * p_launcher);
+  protected:
+    void ShootSound();
+};
+
 GunBullet::GunBullet(ExplosiveWeaponConfig& cfg,
                      WeaponLauncher * p_launcher) :
   WeaponBullet("gun_bullet", cfg, p_launcher)
@@ -43,19 +54,28 @@ GunBullet::GunBullet(ExplosiveWeaponConfig& cfg,
 
 void GunBullet::ShootSound()
 {
-  jukebox.Play("share","weapon/gun");
+  JukeBox::GetInstance()->Play("share","weapon/gun");
 }
 
 //-----------------------------------------------------------------------------
 
 Gun::Gun() : WeaponLauncher(WEAPON_GUN, "gun", new ExplosiveWeaponConfig())
 {
-  m_name = _("Gun");
+  UpdateTranslationStrings();
+
+  m_category = RIFLE;
   m_weapon_fire = new Sprite(resource_manager.LoadImage(weapons_res_profile,m_id+"_fire"));
   m_weapon_fire->EnableRotationCache(32);
   ReloadLauncher();
 }
 
+void Gun::UpdateTranslationStrings()
+{
+  m_name = _("Gun");
+  /* TODO: FILL IT */
+  /* m_help = _(""); */
+}
+
 WeaponProjectile * Gun::GetProjectileInstance()
 {
   return dynamic_cast<WeaponProjectile *>
@@ -64,13 +84,20 @@ WeaponProjectile * Gun::GetProjectileInstance()
 
 bool Gun::p_Shoot()
 {
-  if (m_is_active)
-    return false;  
+  if (IsInUse())
+    return false;
 
-  m_is_active = true;
   projectile->Shoot (GUN_BULLET_SPEED);
   projectile = NULL;
   ReloadLauncher();
   return true;
 }
 
+std::string Gun::GetWeaponWinString(const char *TeamName, uint items_count ) const
+{
+  return Format(ngettext(
+            "%s team has won %u gun!",
+            "%s team has won %u guns!",
+            items_count), TeamName, items_count);
+}
+
