@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,25 +23,16 @@
 #ifndef GUN_H
 #define GUN_H
 
-#include <SDL.h>
-#include <vector>
-#include "launcher.h"
-#include "../include/base.h"
-#include "../tool/point.h"
-
-class GunBullet : public WeaponBullet
-{
-  public:
-    GunBullet(ExplosiveWeaponConfig& cfg,
-              WeaponLauncher * p_launcher);
-  protected:
-    void ShootSound();
-};
+#include "weapon/weapon_launcher.h"
+#include "include/base.h"
 
 class Gun : public WeaponLauncher
 {
   public:
     Gun();
+
+    void UpdateTranslationStrings();
+    std::string GetWeaponWinString(const char *TeamName, uint items_count) const;
   protected:
     bool p_Shoot();
     WeaponProjectile * GetProjectileInstance();
