@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,51 +20,50 @@
  * Sometime the mine didn't explode randomly.
  *****************************************************************************/
 
-#include "mine.h"
+#include "weapon/mine.h"
 #include <iostream>
 #include <sstream>
-#include "explosion.h"
-#include "../game/config.h"
-#include "../game/time.h"
-#include "../graphic/sprite.h"
-#include "../include/app.h"
-#include "../include/constant.h"
-#include "../interface/game_msg.h"
-#include "../map/map.h"
-#include "../object/objects_list.h"
-#include "../team/macro.h"
-#include "../tool/debug.h"
-#include "../tool/i18n.h"
-#include "../network/randomsync.h"
-#include "../tool/resource_manager.h"
+#include "weapon/explosion.h"
+#include "character/character.h"
+#include "game/config.h"
+#include "game/time.h"
+#include "graphic/sprite.h"
+#include "include/constant.h"
+#include "interface/game_msg.h"
+#include "map/camera.h"
+#include "map/map.h"
+#include "object/objects_list.h"
+#include "sound/jukebox.h"
+#include "team/macro.h"
+#include "team/team.h"
+#include "tool/debug.h"
+#include "tool/i18n.h"
+#include "network/randomsync.h"
+#include "tool/resource_manager.h"
+#include "tool/xml_document.h"
 
-#ifdef __MINGW32__
-#undef LoadImage
-#endif
-
-const double DEPART_FONCTIONNEMENT = 5;
+// XXX Not used
+//const double DEPART_FONCTIONNEMENT = 5;
 
 ObjMine::ObjMine(MineConfig& cfg,
                  WeaponLauncher * p_launcher) :
   WeaponProjectile("mine", cfg, p_launcher)
 {
-  m_allow_negative_y = true; 
+  m_allow_negative_y = true;
   animation = false;
-  channel = -1;
   is_active = true;
   explode_with_collision = false;
 
   escape_time = 0;
 
-  // is it a fake mine ?
-  fake = !(randomSync.GetLong(0, 9));
+  fake = false;
 }
 
 void ObjMine::FakeExplosion()
 {
   MSG_DEBUG("mine", "Fake explosion");
 
-  jukebox.Play("share", "weapon/mine_fake");
+  JukeBox::GetInstance()->Play("share", "weapon/mine_fake");
   ParticleEngine::AddNow(GetPosition(), 5, particle_SMOKE, true);
 
   if ( animation )
@@ -84,11 +83,18 @@ void ObjMine::StartTimeout()
   if (!animation)
   {
     animation=true;
+
+    // is it a fake mine ? (here because Constructor is called before random
+    // number generator is synchronized over the network)
+    fake = !(randomSync.GetLong(0, 9));
+
+    Camera::GetInstance()->FollowObject(this, true);
+
     MSG_DEBUG("mine", "EnableDetection - CurrentTime : %d",Time::GetInstance()->ReadSec() );
     attente = Time::GetInstance()->ReadSec() + cfg.timeout;
     MSG_DEBUG("mine", "EnableDetection : %d", attente);
 
-    channel = jukebox.Play("share", "weapon/mine_beep", -1);
+    timeout_sound.Play("share", "weapon/mine_beep", -1);
   }
 }
 
@@ -105,7 +111,7 @@ void ObjMine::Detection()
 
   if (current_time < escape_time) return;
 
-  MSG_DEBUG("mine", "Escape_time is finished : %d", current_time);
+  //MSG_DEBUG("mine", "Escape_time is finished : %d", current_time);
 
   double detection_range = static_cast<MineConfig&>(cfg).detection_range;
 
@@ -119,16 +125,16 @@ void ObjMine::Detection()
       return;
     }
   }
+
   double speed_detection = static_cast<MineConfig&>(cfg).speed_detection;
   double norm, angle;
   FOR_EACH_OBJECT(obj) {
     if ((*obj) != this && !animation && GetName() != (*obj)->GetName() &&
         MeterDistance(GetCenter(), (*obj)->GetCenter()) < detection_range) {
+
       (*obj)->GetSpeed(norm, angle);
-      if(norm < speed_detection) {
-        std::string txt = Format(_("%s is next to a mine!"),
-                                 (*obj)->GetName().c_str());
-        GameMessages::GetInstance()->Add(txt);
+      if (norm < speed_detection && norm > 0.0) {
+        MSG_DEBUG("mine", "norm: %d, speed_detection: %d", norm, speed_detection);
         StartTimeout();
         return;
       }
@@ -136,11 +142,12 @@ void ObjMine::Detection()
   }
 }
 
-void ObjMine::AddDamage(uint damage_points)
+void ObjMine::SetEnergyDelta(int delta, bool do_report)
 {
+  WeaponProjectile::SetEnergyDelta(delta, do_report);
   // Don't call Explosion here, we're already in an explosion
   attente = 0;
-  animation=true;
+  animation = true;
 }
 
 void ObjMine::Refresh()
@@ -149,8 +156,7 @@ void ObjMine::Refresh()
   // or it's a fake mine that has already exploded!
   if (!is_active)
   {
-    jukebox.Stop(channel);
-    channel = -1;
+    timeout_sound.Stop();
     escape_time = 0;
     return;
   }
@@ -160,7 +166,7 @@ void ObjMine::Refresh()
   {
     Detection();
   }
-  else 
+  else
   {
     image->Update();
 
@@ -168,18 +174,22 @@ void ObjMine::Refresh()
     if (attente < Time::GetInstance()->ReadSec())
     {
       is_active = false;
-      jukebox.Stop(channel);
-      channel = -1;
-      if (!fake) Explosion();
-      else FakeExplosion();
-      if (launcher != NULL) launcher->SignalProjectileTimeout();
+      timeout_sound.Stop();
+      if (!fake)
+        Explosion();
+      else
+        FakeExplosion();
+
+      if (launcher != NULL)
+        launcher->SignalProjectileTimeout();
     }
   }
 }
 
 bool ObjMine::IsImmobile() const
 {
-  if (is_active && animation) return false;
+  if (is_active && animation)
+    return false;
   return PhysicalObj::IsImmobile();
 }
 
@@ -188,25 +198,23 @@ void ObjMine::Draw()
   image->Draw(GetPosition());
 }
 //-----------------------------------------------------------------------------
-
-MineConfig * MineConfig::singleton = NULL;
-
-MineConfig * MineConfig::GetInstance() 
-{
-  if (singleton == NULL) {
-    singleton = new MineConfig();
-  }
-  return singleton;
-}
-
 //-----------------------------------------------------------------------------
 
 Mine::Mine() : WeaponLauncher(WEAPON_MINE, "minelauncher", MineConfig::GetInstance(), VISIBLE_ONLY_WHEN_INACTIVE)
 {
-  m_name = _("Mine");
+  UpdateTranslationStrings();
+
+  m_category = THROW;
   ReloadLauncher();
 }
 
+void Mine::UpdateTranslationStrings()
+{
+    m_name = _("Mine");
+    /* TODO: FILL IT */
+    /* m_help = _(""); */
+}
+
 WeaponProjectile * Mine::GetProjectileInstance()
 {
   return dynamic_cast<WeaponProjectile *>
@@ -222,19 +230,38 @@ bool Mine::p_Shoot()
   return true;
 }
 
-void Mine::Add (int x, int y)
+void Mine::Add(int x, int y)
 {
-  projectile -> SetXY ( Point2i(x, y) );
-  projectile -> SetOverlappingObject(&ActiveCharacter());
+  projectile->SetXY(Point2i(x, y));
+  projectile->SetOverlappingObject(&ActiveCharacter());
 
-  Point2d speed_vector;
-  ActiveCharacter().GetSpeedXY(speed_vector);
-  projectile -> SetSpeedXY (speed_vector);
+  projectile -> SetSpeedXY (ActiveCharacter().GetSpeedXY());
   lst_objects.AddObject (projectile);
   projectile = NULL;
   ReloadLauncher();
 }
 
+std::string Mine::GetWeaponWinString(const char *TeamName, uint items_count ) const
+{
+  return Format(ngettext(
+            "%s team has won %u mine!",
+            "%s team has won %u mines!",
+            items_count), TeamName, items_count);
+}
+
+//-----------------------------------------------------------------------------
+//-----------------------------------------------------------------------------
+
+MineConfig * MineConfig::singleton = NULL;
+
+MineConfig * MineConfig::GetInstance()
+{
+  if (singleton == NULL) {
+    singleton = new MineConfig();
+  }
+  return singleton;
+}
+
 MineConfig& Mine::cfg()
 {
   return static_cast<MineConfig&>(*extra_params);
@@ -244,11 +271,11 @@ MineConfig::MineConfig()
 {
   detection_range = 1;
   speed_detection = 2;
-  timeout = 3;
+  timeout = 2;
   escape_time = 2;
 }
 
-void MineConfig::LoadXml(xmlpp::Element *elem) 
+void MineConfig::LoadXml(xmlNode* elem)
 {
   ExplosiveWeaponConfig::LoadXml (elem);
   XmlReader::ReadUint(elem, "escape_time", escape_time);
