@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,22 +22,17 @@
 #ifndef MINE_H
 #define MINE_H
 
-#include <SDL.h>
-#include "launcher.h"
-#include "../graphic/surface.h"
-#include "../graphic/sprite.h"
-#include "../include/base.h"
-#include "../object/physical_obj.h"
-#include "../character/character.h"
+#include "weapon_cfg.h"
+#include "weapon/weapon_launcher.h"
+#include "include/base.h"
 
 class Mine;
 class MineConfig;
 
 class ObjMine : public WeaponProjectile
 {
-  private:
-  // channel used for sound
-    int channel;
+private:
+    SoundSample timeout_sound;
 
   // this is a fake mine ?
     bool fake;
@@ -60,17 +55,17 @@ class ObjMine : public WeaponProjectile
     void Detection();
     virtual bool IsImmobile() const;
     // Damage handling
-    virtual void AddDamage(uint damage_points);
+    void SetEnergyDelta(int delta, bool do_report = true);
 
     void Draw();
     void Refresh();
 };
 
 class MineConfig : public ExplosiveWeaponConfig
-{ 
+{
   private:
     static MineConfig * singleton;
-  public: 
+  public:
     uint escape_time;
     double detection_range;
     double speed_detection;
@@ -79,7 +74,7 @@ class MineConfig : public ExplosiveWeaponConfig
     MineConfig();
   public:
     static MineConfig * GetInstance();
-    virtual void LoadXml(xmlpp::Element *elem);
+    virtual void LoadXml(xmlNode* elem);
 };
 
 class Mine : public WeaponLauncher
@@ -90,9 +85,10 @@ class Mine : public WeaponLauncher
     WeaponProjectile * GetProjectileInstance();
     bool p_Shoot();
   public:
+    void UpdateTranslationStrings();
+    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
     Mine();
     MineConfig& cfg();
-  
 };
 
 #endif /* MINE_H */
