@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,29 +16,21 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  ******************************************************************************
- * 
+ *
  *****************************************************************************/
 
 #ifndef RIOT_BOMB_H
 #define RIOT_BOMB_H
-#include "launcher.h"
 
-// Roquette du bazooka
-class RiotBombRocket : public WeaponProjectile
-{
-public:
-  RiotBombRocket(ExplosiveWeaponConfig& cfg,
-                   WeaponLauncher * p_launcher);
-  void Refresh();
-protected:
-  void SignalOutOfMap();
-  void DoExplosion();
-};
+#include "weapon/weapon_launcher.h"
 
 class RiotBomb : public WeaponLauncher
 {
  public:
   RiotBomb();
+
+  void UpdateTranslationStrings();
+  std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
  protected:
   WeaponProjectile * GetProjectileInstance();
 };
