@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,41 +19,58 @@
  * Skip his turn
  *****************************************************************************/
 
-#include "skip_turn.h"
+#include "weapon/skip_turn.h"
+#include "weapon/weapon_cfg.h"
+
 //-----------------------------------------------------------------------------
-#include "../game/game_loop.h"
-#include "../interface/game_msg.h"
-#include "../team/teams_list.h"
-#include "../tool/i18n.h"
+#include "character/character.h"
+#include "game/time.h"
+#include "interface/game_msg.h"
+#include "sound/jukebox.h"
+#include "team/teams_list.h"
+#include "team/team.h"
+#include "tool/i18n.h"
 //-----------------------------------------------------------------------------
 
 SkipTurn::SkipTurn() : Weapon(WEAPON_SKIP_TURN, "skip_turn", new WeaponConfig())
+{
+  UpdateTranslationStrings();
+
+  m_category = TOOL;
+  m_time_between_each_shot = 40;
+}
+
+//-----------------------------------------------------------------------------
+
+void SkipTurn::UpdateTranslationStrings()
 {
   m_name = _("Skip turn");
+  /* TODO: FILL IT */
+  /* m_help = _(""); */
 }
 
 //-----------------------------------------------------------------------------
 
 bool SkipTurn::p_Shoot()
 {
-
   // Show message
   GameMessages::GetInstance()->Add (Format(_("%s team has skipped its turn."),
-			      ActiveTeam().GetName().c_str()));
-
-  jukebox.Play(ActiveTeam().GetSoundProfile(), "skip_turn");
-
-  // End turn
-  m_is_active = false;
+                                           ActiveTeam().GetName().c_str()));
+  JukeBox::GetInstance()->Play(ActiveTeam().GetSoundProfile(), "skip_turn");
   return true;
 }
 
 //-----------------------------------------------------------------------------
 
-void SkipTurn::Refresh()
+std::string SkipTurn::GetWeaponWinString(const char *TeamName, uint items_count ) const
 {
-  if (m_is_active)
-    m_is_active = false;
+  return Format(ngettext(
+            "%s team has won %u turn skip! I know you'll love it.",
+            "%s team has won %u turn skips! I know you'll love them.",
+            items_count), TeamName, items_count);
 }
 
-//-----------------------------------------------------------------------------
+bool SkipTurn::IsInUse() const
+{
+  return m_last_fire_time + m_time_between_each_shot > Time::GetInstance()->Read();
+}
