@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,55 +19,63 @@
  * Suicide.
  *****************************************************************************/
 
-#include "suicide.h"
+#include "weapon/suicide.h"
+#include "weapon/explosion.h"
+#include "weapon/weapon_cfg.h"
+
 #include <iostream>
-#include "explosion.h"
-#include "../character/body.h"
-#include "../game/game_loop.h"
-#include "../team/teams_list.h"
-#include "../tool/i18n.h"
-#include "../include/action_handler.h"
+#include "character/character.h"
+#include "character/body.h"
+#include "team/teams_list.h"
+#include "tool/i18n.h"
+#include "include/action_handler.h"
 
 Suicide::Suicide() : Weapon(WEAPON_SUICIDE, "suicide", new ExplosiveWeaponConfig())
 {
-  m_name = _("Commit Suicide");
-  sound_channel = -1;
+  UpdateTranslationStrings();
+
+  m_category = DUEL;
 }
 
-void Suicide::p_Select()
+void Suicide::UpdateTranslationStrings()
 {
-  is_dying = false;
+  m_name = _("Commit Suicide");
+  /* TODO: FILL IT */
+  /* m_help = _(""); */
 }
 
 bool Suicide::p_Shoot()
 {
-  sound_channel = jukebox.Play ("share", "weapon/suicide");
-
-  GameLoop::GetInstance()->interaction_enabled=false;
-  is_dying = true;
-
+  suicide_sound.Play ("share", "weapon/suicide");
   return true;
 }
 
 void Suicide::Refresh()
 {
-  if (!is_dying) return;
-
-  m_is_active = sound_channel != -1 && Mix_Playing(sound_channel);
-
-  if(!m_is_active && !ActiveCharacter().IsDead())
-  {
+  if(m_last_fire_time > 0 && !suicide_sound.IsPlaying() && !ActiveCharacter().IsDead()) {
     ActiveCharacter().DisableDeathExplosion();
     ActiveCharacter().body->MakeParticles(ActiveCharacter().GetPosition());
-    Action* a = new Action(Action::ACTION_SET_CHARACTER_ENERGY);
-    a->Push((int)ActiveCharacter().GetTeamIndex());
-    a->Push((int)ActiveCharacter().GetCharacterIndex());
-    a->Push(0); // Set energy to 0 => death
-    ActionHandler::GetInstance()->NewAction(a);
+    ActiveCharacter().SetEnergy(0); // Die!
+    SendActiveCharacterInfo();
     ApplyExplosion(ActiveCharacter().GetCenter(),cfg());
   }
 }
 
+bool Suicide::IsInUse() const
+{
+  return m_last_fire_time > 0 && !ActiveCharacter().IsDead();
+}
+
 ExplosiveWeaponConfig& Suicide::cfg()
-{ return static_cast<ExplosiveWeaponConfig&>(*extra_params); }
+{
+  return static_cast<ExplosiveWeaponConfig&>(*extra_params);
+}
+
+std::string Suicide::GetWeaponWinString(const char *TeamName, uint items_count) const
+{
+  return Format(ngettext(
+            "%s team has won %u suicide!",
+            "%s team has won %u suicides! Use them all for an extra bonus!",
+            items_count), TeamName, items_count);
+}
 
