@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,20 +23,23 @@
 #define SUICIDE_H
 
 #include "weapon.h"
-#include "graphic/surface.h"
+
+class ExplosiveWeaponConfig;
 
 class Suicide : public Weapon
 {
   private:
-    int sound_channel;
-    bool is_dying;
+    SoundSample suicide_sound;
   protected:
     bool p_Shoot();
-    void p_Select();
     void Refresh();
   public:
     Suicide();
     ExplosiveWeaponConfig &cfg();
+    bool IsInUse() const;
+
+    void UpdateTranslationStrings();
+    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
 };
 
 #endif /* SUICIDE_H */
