@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,59 +16,43 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  ******************************************************************************
- * Arme Supertux : Look ! it's the famous flying magic pinguin !
+ * Weapon Supertux : Look ! it's the famous flying magic pinguin !
  *****************************************************************************/
 
 #ifndef SUPERTUX_H
 #define SUPERTUX_H
 
-#include "launcher.h"
-#include "../graphic/surface.h"
-#include "../gui/progress_bar.h"
-#include "../include/base.h"
-#include "../object/physical_obj.h"
+#include "weapon/weapon_launcher.h"
+#include "particles/particle.h"
 
-class TuxLauncher;
+class SuperTux;
 
-class SuperTuxWeaponConfig : public ExplosiveWeaponConfig
-{
-  public:
-    uint speed;
-    SuperTuxWeaponConfig();
-    virtual void LoadXml(xmlpp::Element *elem);
-};
-
-class SuperTux : public WeaponProjectile
-{
-  private:
-    ParticleEngine particle_engine;
-    double angle_rad;
-
-  public:
-    uint speed;
-    uint time_now;
-    uint time_next_action;
-    uint last_move;
-
-    SuperTux(SuperTuxWeaponConfig& cfg,
-             WeaponLauncher * p_launcher);
-    void Refresh();
-
-    inline void SetAngle(double angle) {angle_rad = angle;}
-    void turn_left();
-    void turn_right();
-    void Shoot(double strength);
-  protected:
-    void SignalOutOfMap();
-};
+class SuperTuxWeaponConfig;
 
 class TuxLauncher : public WeaponLauncher
 {
   private:
     SuperTux * current_tux;
+
+    friend class SuperTux;
+    void EndOfTurn() const; // should be called only by SuperTux
   public:
     TuxLauncher();
-    void HandleKeyEvent(Action::Action_t action, Keyboard::Key_Event_t event_type);
+    bool IsInUse() const;
+
+    void UpdateTranslationStrings();
+    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
+
+    void SignalEndOfProjectile();
+    void HandleKeyPressed_MoveRight(bool shift);
+    void HandleKeyRefreshed_MoveRight(bool shift);
+    void HandleKeyReleased_MoveRight(bool shift);
+    void HandleKeyPressed_MoveLeft(bool shift);
+    void HandleKeyRefreshed_MoveLeft(bool shift);
+    void HandleKeyReleased_MoveLeft(bool shift);
+
+    void RefreshFromNetwork(double angle, Point2d pos);
+
   protected:
     WeaponProjectile * GetProjectileInstance();
     bool p_Shoot();
