@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,26 +19,37 @@
  * Teleportation : move a charecter anywhere on the map
  *****************************************************************************/
 
-#include "teleportation.h"
-#include "../character/body.h"
-#include "../game/game_loop.h"
-#include "../game/game_mode.h"
-#include "../game/time.h"
-#include "../graphic/effects.h"
-#include "../include/action_handler.h"
-#include "../interface/mouse.h"
-#include "../map/camera.h"
-#include "../map/map.h"
-#include "../particles/teleport_member.h"
-#include "../team/teams_list.h"
-#include "../tool/i18n.h"
+#include "weapon/teleportation.h"
+#include "character/character.h"
+#include "character/body.h"
+#include "game/game_mode.h"
+#include "game/time.h"
+#include "include/action_handler.h"
+#include "interface/mouse.h"
+#include "map/camera.h"
+#include "map/map.h"
+#include "particles/teleport_member.h"
+#include "sound/jukebox.h"
+#include "team/teams_list.h"
+#include "tool/i18n.h"
 
 Teleportation::Teleportation() : Weapon(WEAPON_TELEPORTATION, "teleportation",
-					new WeaponConfig(),
-					VISIBLE_ONLY_WHEN_INACTIVE)
+                                        new WeaponConfig(),
+                                        VISIBLE_ONLY_WHEN_INACTIVE)
+{
+  UpdateTranslationStrings();
+
+  m_category = MOVE;
+  target_chosen = false;
+  // teleportation_anim_duration is declare in particles/teleport_member.h
+  m_time_between_each_shot = teleportation_anim_duration + 100;
+}
+
+void Teleportation::UpdateTranslationStrings()
 {
   m_name = _("Teleportation");
-  target_chosen = false;
+  /* TODO: FILL IT */
+  /* m_help = _(""); */
 }
 
 bool Teleportation::p_Shoot ()
@@ -51,16 +62,15 @@ bool Teleportation::p_Shoot ()
     return false;
 
   Rectanglei rect = ActiveCharacter().GetTestRect();
-  rect.SetPosition(dst); 
+  rect.SetPosition(dst);
 
   // Go back to default cursor
   Mouse::GetInstance()->SetPointer(Mouse::POINTER_SELECT);
-  
-  GameLoop::GetInstance()->interaction_enabled = false;
 
-  jukebox.Play("share", "weapon/teleport_start");
+  //  Game::GetInstance()->interaction_enabled = false;
+
+  JukeBox::GetInstance()->Play("share", "weapon/teleport_start");
 
-  time = Time::GetInstance()->Read();
   ActiveCharacter().Hide();
   ActiveCharacter().body->MakeTeleportParticles(ActiveCharacter().GetPosition(), dst);
 
@@ -70,38 +80,28 @@ bool Teleportation::p_Shoot ()
 
 void Teleportation::Refresh()
 {
-  if (!m_is_active) return;
-
-  double dt = Time::GetInstance()->Read() - time;
-
-  if(dt > teleportation_anim_duration)
-  {
-    camera.SetXYabs(dst - camera.GetSize()/2);
+  if(Time::GetInstance()->Read() - m_last_fire_time > (int)teleportation_anim_duration) {
+    Camera::GetInstance()->SetXYabs(dst - Camera::GetInstance()->GetSize() / 2);
     ActiveCharacter().SetXY(dst);
-    m_is_active = false;
-    ActiveCharacter().SetSpeed(0.0,0.0);
+    ActiveCharacter().SetSpeed(0.0, 0.0);
     ActiveCharacter().Show();
-    jukebox.Play("share","weapon/teleport_end");
-    GameLoop::GetInstance()->interaction_enabled = true;
+    JukeBox::GetInstance()->Play("share", "weapon/teleport_end");
     return;
   }
 }
 
-void Teleportation::Draw()
-{
-  if (!m_is_active)
-    Weapon::Draw();
-}
-
 void Teleportation::p_Select()
 {
-  Mouse::GetInstance()->SetPointer(Mouse::POINTER_FIRE_RIGHT);
+  Mouse::GetInstance()->SetPointer(Mouse::POINTER_FIRE_LEFT);
+  Weapon::p_Select();
+  target_chosen = false;
 }
 
 void Teleportation::p_Deselect()
 {
   // Go back to default cursor
   Mouse::GetInstance()->SetPointer(Mouse::POINTER_SELECT);
+  Weapon::p_Deselect();
 }
 
 void Teleportation::ChooseTarget(Point2i mouse_pos)
@@ -114,6 +114,20 @@ void Teleportation::ChooseTarget(Point2i mouse_pos)
   Shoot();
 }
 
-WeaponConfig& Teleportation::cfg()
-{ return static_cast<WeaponConfig&>(*extra_params); }
+std::string Teleportation::GetWeaponWinString(const char *TeamName, uint items_count ) const
+{
+  return Format(ngettext(
+            "%s team has won %u teleportation!",
+            "%s team has won %u teleportations!",
+            items_count), TeamName, items_count);
+}
 
+WeaponConfig& Teleportation::cfg()
+{
+  return static_cast<WeaponConfig&>(*extra_params);
+}
+
+bool Teleportation::IsInUse() const
+{
+  return m_last_fire_time > 0 && m_last_fire_time + m_time_between_each_shot > Time::GetInstance()->Read();
+}
