@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,15 +21,16 @@
 
 #ifndef TELEPORTATION_H
 #define TELEPORTATION_H
+
 #include "weapon.h"
-#include "../include/base.h"
-#include "../tool/point.h"
+
+class WeaponConfig;
 
 class Teleportation : public Weapon
 {
   private:
     bool target_chosen;
-    uint time;
+    uint animation_duration;
     Point2i src, dst;
   protected:
     bool p_Shoot();
@@ -38,9 +39,13 @@ class Teleportation : public Weapon
     void Refresh();
   public:
     Teleportation();
-    void Draw();
+    void Draw() { if (!IsInUse()) Weapon::Draw(); };
     void ChooseTarget(Point2i mouse_pos);
+    bool IsInUse() const;
     WeaponConfig& cfg();
+
+    void UpdateTranslationStrings();
+    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
 };
 
 #endif /* TELEPORTATION_H */
