@@ -1,6 +1,6 @@
 /******************************************************************************
  *  Wormux is a convivial mass murder game.
- *  Copyright (C) 2001-2004 Lawrence Azzoug.
+ *  Copyright (C) 2001-2008 Wormux Team.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,39 +25,41 @@
 #include <list>
 #include <map>
 #include "weapon.h"
-#include "../include/base.h"
+#include "include/base.h"
+#include "include/singleton.h"
 //-----------------------------------------------------------------------------
 
 // Classe de gestion des armes
-class WeaponsList
+class WeaponsList : public Singleton<WeaponsList>
 {
 public:
   typedef std::list<Weapon*> weapons_list_type;
-  typedef std::list<Weapon*>::iterator weapons_list_it;
+  typedef std::list<Weapon*>::const_iterator weapons_list_it;
 
 private:
   weapons_list_type m_weapons_list;
-
-  // The int is used to classify weapon by sort
-  std::multimap<uint, Weapon*> m_weapons_map;
-  typedef std::multimap<uint, Weapon*>::value_type keybind;
-  typedef std::multimap<uint, Weapon*>::iterator weapons_map_it;
-  void AddToList(Weapon* arme, uint num_sort);
   Weapon* GetNextWeapon(uint sort, uint index);
 
-public:
+protected:
+  friend class Singleton<WeaponsList>;
+  /* if you need to use this, implement it */
+  WeaponsList(const WeaponsList &a_list);
   WeaponsList();
   ~WeaponsList();
+
+public:
   void Init();
 
-  // Refresh des armes
-  // Retourne true si c'est la fin d'un tour
-  void Refresh();
+  // Weapon refresh
+  // Return true if end of turn
+  void Refresh() const;
+
+  static void UpdateTranslation();
 
   // Return a list of  weapons
-  weapons_list_type& GetList();
+  const weapons_list_type& GetList() const { return m_weapons_list; };
   Weapon* GetWeapon(Weapon::Weapon_type type);
-  bool GetWeaponBySort(uint num_sort, Weapon::Weapon_type &type);
+  bool GetWeaponBySort(Weapon::category_t num_sort, Weapon::Weapon_type &type);
 };
 
 //-----------------------------------------------------------------------------
